@@ -32,15 +32,15 @@
 
 
 #include <vector>
-#include "../utils/utils.h"
+#include <pthread.h>
 #include "midiMapConf.h"
-#include "const.h"
 #include "recorder.h"
 
 #ifdef WITH_VST
-	#include "../deps/juce/config.h"
+	#include "../deps/juce-config.h"
 #endif
 
+
 using std::vector;
 using std::string;
 
@@ -91,12 +91,6 @@ public:
 
 	virtual void copy(const Channel *src, pthread_mutex_t *pluginMutex) = 0;
 
-	/* writePatch
-	 * Fill a patch with channel values. Returns the index of the last
-	 * Patch::channel_t added. */
-
-	virtual int writePatch(int i, bool isProject, class Patch *patch);
-
 	/* readPatch
 	 * Fill channel with data from patch. */
 
@@ -106,16 +100,19 @@ public:
 			pthread_mutex_t *pluginMutex, int samplerate, int rsmpQuality);
 
 	/* process
-	 * merge vChannels into buffer, plus plugin processing (if any). */
+	Merges vChannels into buffer, plus plugin processing (if any). Warning:
+	inBuffer might be nullptr if no input devices are available for recording. */
 
-	virtual void process(float *buffer) = 0;
+	virtual void process(float *outBuffer, float *inBuffer) = 0;
 
 	/* start
-	 * action to do when channel starts. doQuantize = false (don't
-	 * quantize) when Mixer is reading actions from Recorder::. */
+	Action to do when channel starts. doQuantize = false (don't quantize)
+	when Mixer is reading actions from Recorder. If isUserGenerated means that
+	the channel has been started by a human key press and not a pre-recorded
+	action. */
 
 	virtual void start(int frame, bool doQuantize, int quantize,
-			bool mixerIsRunning) = 0;
+			bool mixerIsRunning, bool forceStart, bool isUserGenerated) = 0;
 
 	/* stop
 	 * action to do when channel is stopped normally (via key or MIDI). */
@@ -146,10 +143,10 @@ public:
 
 	/* quantize
 	 * start channel according to quantizer. Index = array index of
-	 * mixer::channels, used by recorder. LocalFrame = frame within buffer.
-	 * GloalFrame = actual frame from mixer. */
+	 * mixer::channels, used by recorder. LocalFrame = frame within the current
+   * buffer.  */
 
-	virtual void quantize(int index, int localFrame, int globalFrame) = 0;
+	virtual void quantize(int index, int localFrame, class Mixer *m) = 0;
 
 	/* onZero
 	 * action to do when frame goes to zero, i.e. sequencer restart. */
@@ -167,7 +164,9 @@ public:
 	 * localFrame  - frame number of the processed buffer
 	 * globalFrame - actual frame in Mixer */
 
-	virtual void parseAction(recorder::action *a, int localFrame, int globalFrame,
+	 // TODO - quantize is useless!
+
+	virtual void parseAction(Recorder::action *a, int localFrame, int globalFrame,
 			int quantize, bool mixerIsRunning) = 0;
 
 	/* rewind
@@ -175,25 +174,50 @@ public:
 
 	virtual void rewind() = 0;
 
+	/* clear
+	Clears all memory buffers. This is actually useful to sample channels only. */
+
+	virtual void clear() = 0;
+
+	/* canInputRec
+	Tells whether a channel can accept and handle input audio. Always false for
+	Midi channels, true for Sample channels only if they don't contain a
+	sample yet.*/
+
+	virtual bool canInputRec() = 0;
+
+	/* writePatch
+	 * Fill a patch with channel values. Returns the index of the last
+	 * Patch::channel_t added. */
+
+	virtual int writePatch(int i, bool isProject, class Patch *patch);
+
+	/* receiveMidi
+	 * Receives and processes midi messages from external devices. */
+
+	virtual void receiveMidi(uint32_t msg);
+
 	/* ------------------------------------------------------------------------ */
 
-	int     index;                // unique id
-	int     type;                 // midi or sample
-	int     status;	              // status: see const.h
-	int     key;                  // keyboard button
-	float   volume;               // global volume
-	float   volume_i;             // internal volume
-	float   volume_d;             // delta volume (for envelope)
+	int     index;                 // unique id
+	int     type;                  // midi or sample
+	int     status;	               // status: see const.h
+	int     key;                   // keyboard button
+	float   volume;                // global volume
+	float   volume_i;              // internal volume
+	float   volume_d;              // delta volume (for envelope)
 	float   panLeft;
 	float   panRight;
-	bool    mute_i;               // internal mute
-	bool 	  mute_s;               // previous mute status after being solo'd
-	bool    mute;                 // global mute
+	bool    mute_i;                // internal mute
+	bool 	  mute_s;                // previous mute status after being solo'd
+	bool    mute;                  // global mute
 	bool    solo;
-  bool    hasActions;           // has something recorded
-	int 	  recStatus;            // status of recordings (waiting, ending, ...)
-	float  *vChan;	              // virtual channel
-  class   gChannel *guiChannel; // pointer to a gChannel object, part of the GUI
+  bool    hasActions;            // has something recorded
+  bool    readActions;           // read what's recorded
+	bool    armed;							   // armed for recording
+	int 	  recStatus;             // status of recordings (waiting, ending, ...)
+	float  *vChan;	               // virtual channel
+  class   geChannel *guiChannel; // pointer to a gChannel object, part of the GUI
 
 	// TODO - midi structs, please
 
@@ -201,6 +225,7 @@ public:
   uint32_t midiInKeyPress;
   uint32_t midiInKeyRel;
   uint32_t midiInKill;
+  uint32_t midiInArm;
   uint32_t midiInVolume;
   uint32_t midiInMute;
   uint32_t midiInSolo;
@@ -253,7 +278,9 @@ public:
 	 * Return a reference to midiBuffer stack. This is available for any kind of
 	 * channel, but it makes sense only for MIDI channels. */
 
-	juce::MidiBuffer &getPluginMidiEvents() { return midiBuffer; };
+	juce::MidiBuffer &getPluginMidiEvents();
+
+	void clearMidiBuffer();
 
 #endif
 };
