@@ -30,7 +30,7 @@
 #include <string>
 #include "conf.h"
 #include "const.h"
-#include "../utils/utils.h"
+#include "../utils/fs.h"
 #include "../utils/log.h"
 
 
@@ -44,8 +44,8 @@ Conf::Conf()
 
 #if defined(__linux__) || defined(__APPLE__)
 
-	confFilePath = gGetHomePath() + G_SLASH + CONF_FILENAME;
-	confDirPath  = gGetHomePath() + G_SLASH;
+	confFilePath = gu_getHomePath() + G_SLASH + CONF_FILENAME;
+	confDirPath  = gu_getHomePath() + G_SLASH;
 
 #elif defined(_WIN32)
 
@@ -63,17 +63,17 @@ int Conf::createConfigFolder()
 {
 #if defined(__linux__) || defined(__APPLE__)
 
-	if (gDirExists(confDirPath))
+	if (gu_dirExists(confDirPath))
 		return 1;
 
-	gLog("[Conf::createConfigFolder] .giada folder not present. Updating...\n");
+	gu_log("[Conf::createConfigFolder] .giada folder not present. Updating...\n");
 
-	if (gMkdir(confDirPath)) {
-		gLog("[Conf::createConfigFolder] status: ok\n");
+	if (gu_mkdir(confDirPath)) {
+		gu_log("[Conf::createConfigFolder] status: ok\n");
 		return 1;
 	}
 	else {
-		gLog("[Conf::createConfigFolder] status: error!\n");
+		gu_log("[Conf::createConfigFolder] status: error!\n");
 		return 0;
 	}
 
@@ -154,6 +154,11 @@ void Conf::init()
 	sampleEditorW = 640;
 	sampleEditorH = 480;
 
+  midiInputX = 0;
+  midiInputY = 0;
+  midiInputW = G_DEFAULT_MIDI_INPUT_UI_W;
+  midiInputH = G_DEFAULT_MIDI_INPUT_UI_H;
+
 	pianoRollY = -1;
 	pianoRollH = 422;
 
@@ -178,7 +183,7 @@ int Conf::read()
 
 	jRoot = json_load_file(confFilePath.c_str(), 0, &jError);
   if (!jRoot) {
-    gLog("[Conf::read] unable to read configuration file! Error on line %d: %s\n", jError.line, jError.text);
+    gu_log("[Conf::read] unable to read configuration file! Error on line %d: %s\n", jError.line, jError.text);
     return 0;
   }
 
@@ -260,6 +265,10 @@ int Conf::read()
 	if (!setInt(jRoot, CONF_KEY_BEATS_Y, beatsY)) return 0;
 	if (!setInt(jRoot, CONF_KEY_ABOUT_X, aboutX)) return 0;
 	if (!setInt(jRoot, CONF_KEY_ABOUT_Y, aboutY)) return 0;
+  if (!setInt(jRoot, CONF_KEY_MIDI_INPUT_X, midiInputX)) return 0;
+  if (!setInt(jRoot, CONF_KEY_MIDI_INPUT_Y, midiInputY)) return 0;
+  if (!setInt(jRoot, CONF_KEY_MIDI_INPUT_W, midiInputW)) return 0;
+  if (!setInt(jRoot, CONF_KEY_MIDI_INPUT_H, midiInputH)) return 0;
 
 #ifdef WITH_VST
 
@@ -361,6 +370,10 @@ int Conf::write()
 	json_object_set_new(jRoot, CONF_KEY_BEATS_Y,                   json_integer(beatsY));
 	json_object_set_new(jRoot, CONF_KEY_ABOUT_X,                   json_integer(aboutX));
 	json_object_set_new(jRoot, CONF_KEY_ABOUT_Y,                   json_integer(aboutY));
+	json_object_set_new(jRoot, CONF_KEY_MIDI_INPUT_X,              json_integer(midiInputX));
+	json_object_set_new(jRoot, CONF_KEY_MIDI_INPUT_Y,              json_integer(midiInputY));
+	json_object_set_new(jRoot, CONF_KEY_MIDI_INPUT_W,              json_integer(midiInputW));
+	json_object_set_new(jRoot, CONF_KEY_MIDI_INPUT_H,              json_integer(midiInputH));
 
 #ifdef WITH_VST
 
@@ -373,7 +386,7 @@ int Conf::write()
 #endif
 
   if (json_dump_file(jRoot, confFilePath.c_str(), JSON_INDENT(2)) != 0) {
-    gLog("[Conf::write] unable to write configuration file!\n");
+    gu_log("[Conf::write] unable to write configuration file!\n");
     return 0;
   }
   return 1;
@@ -413,11 +426,19 @@ void Conf::sanitize()
 	if (sampleEditorH < 292) sampleEditorH = 292;
 	if (sampleEditorGridVal < 0) sampleEditorGridVal = 0;
 	if (sampleEditorGridOn < 0) sampleEditorGridOn = 0;
+  if (midiInputX < 0) midiInputX = 0;
+  if (midiInputY < 0) midiInputY = 0;
+  if (midiInputW < G_DEFAULT_MIDI_INPUT_UI_W) midiInputW = G_DEFAULT_MIDI_INPUT_UI_W;
+  if (midiInputH < G_DEFAULT_MIDI_INPUT_UI_H) midiInputH = G_DEFAULT_MIDI_INPUT_UI_H;
 	if (configX < 0) configX = 0;
 	if (configY < 0) configY = 0;
 	if (pluginListX < 0) pluginListX = 0;
 	if (pluginListY < 0) pluginListY = 0;
-	if (bpmX < 0) bpmX = 0;
+#ifdef WITH_VST
+	if (pluginChooserW < 640) pluginChooserW = 640;
+	if (pluginChooserH < 480) pluginChooserW = 480;
+#endif
+  if (bpmX < 0) bpmX = 0;
 	if (bpmY < 0) bpmY = 0;
 	if (beatsX < 0) beatsX = 0;
 	if (beatsY < 0) beatsY = 0;
