@@ -32,11 +32,11 @@
 
 
 /* -- version --------------------------------------------------------------- */
-#define G_VERSION_STR   "0.13.0"
+#define G_VERSION_STR   "0.13.2"
 #define G_APP_NAME      "Giada"
 #define G_VERSION_MAJOR 0
 #define G_VERSION_MINOR 13
-#define G_VERSION_PATCH 0
+#define G_VERSION_PATCH 2
 
 #define CONF_FILENAME		"giada.conf"
 
@@ -64,17 +64,19 @@
 #define GUI_PLUGIN_RATE    0.05  // refresh rate for plugin GUIs
 #define GUI_FONT_SIZE_BASE 12
 
-#define COLOR_BD_0     fl_rgb_color(78,  78,  78)			// border off
+#define COLOR_BD_0     fl_rgb_color(78,  78,  78)			// border off - TODO duplicate!
 #define COLOR_BD_1     fl_rgb_color(188, 188, 188)    // border on
 #define COLOR_BG_0     fl_rgb_color(37,  37,  37)     // bg off
-#define COLOR_BG_1     fl_rgb_color(78,  78,  78)     // bg on (clicked)
+#define COLOR_BG_1     fl_rgb_color(78,  78,  78)     // bg on (clicked) - TODO duplicate!
 #define COLOR_BG_2     fl_rgb_color(177, 142, 142)    // bg active (play, for some widgets)
 #define COLOR_BG_3     fl_rgb_color(28,  32,  80)     // bg input rec
 #define COLOR_BG_4     fl_rgb_color(113, 31,  31)     // bg action rec
 #define COLOR_ALERT    fl_rgb_color(239, 75,  53)     // peak meter alert
 #define COLOR_TEXT_0   fl_rgb_color(200, 200, 200)
-#define COLOR_TEXT_1   fl_rgb_color(25,  25,  25)      // TODO - duplicate!
-#define COLOR_BG_MAIN  fl_rgb_color(25,  25,  25)		   // windows background
+#define COLOR_TEXT_1   fl_rgb_color(25,  25,  25)      // TODO duplicate!
+#define COLOR_BG_MAIN  fl_rgb_color(25,  25,  25)		   // windows background - TODO duplicate!
+#define COLOR_BG_RICH  fl_rgb_color(30,  30,  30)		   // lighter background
+#define COLOR_BG_LINE  fl_rgb_color(54,  54,  54)		   // lighter, for bg lines
 #define COLOR_BG_DARK  fl_rgb_color(0,   0,   0)		   // inputs background
 
 
@@ -128,11 +130,11 @@
 #define DEFAULT_SAMPLERATE   44100
 #define DEFAULT_BUFSIZE		   1024
 #define DEFAULT_DELAYCOMP		 0
-#define DEFAULT_VOL				   0.0f
+#define DEFAULT_VOL				   1.0f
+#define G_DEFAULT_PITCH			 1.0f
 #define DEFAULT_BOOST			   0.0f
-#define gDEFAULT_PITCH			 1.0f   // ugly and temporary fix to avoid conflicts with wingdi.h (Windows only).
 #define DEFAULT_OUT_VOL  	   1.0f
-#define DEFAULT_IN_VOL  	   0.0f
+#define DEFAULT_IN_VOL  	   1.0f
 #define DEFAULT_CHANMODE	   SINGLE_BASIC
 #define DEFAULT_BPM				   120.0f
 #define DEFAULT_BEATS			   4
@@ -140,6 +142,9 @@
 #define DEFAULT_QUANTIZE     0		  // quantizer off
 #define DEFAULT_FADEOUT_STEP 0.01f  // micro-fadeout speed
 #define DEFAULT_COLUMN_WIDTH 380
+#define G_DEFAULT_PATCH_NAME "(default patch)"
+#define G_DEFAULT_MIDI_INPUT_UI_W 300
+#define G_DEFAULT_MIDI_INPUT_UI_H 350
 
 
 
@@ -210,16 +215,6 @@
 
 
 
-/* -- browser types --------------------------------------------------------- */
-#define BROWSER_LOAD_PATCH   0x00
-#define BROWSER_LOAD_SAMPLE  0x01
-#define BROWSER_SAVE_PATCH   0x02
-#define BROWSER_SAVE_SAMPLE  0x04
-#define BROWSER_SAVE_PROJECT 0x08
-#define BROWSER_LOAD_PLUGIN  0x10
-
-
-
 /* -- channel types --------------------------------------------------------- */
 #define CHANNEL_SAMPLE 0x01
 #define CHANNEL_MIDI   0x02
@@ -268,6 +263,7 @@
 #define MIDI_CONTROLLER     0xB0 << 24
 #define MIDI_NOTE_ON        0x90 << 24
 #define MIDI_NOTE_OFF       0x80 << 24
+#define MIDI_VELOCITY       0x3F <<  8
 #define MIDI_ALL_NOTES_OFF (MIDI_CONTROLLER) | (0x7B << 16)
 #define MIDI_VOLUME        (MIDI_CONTROLLER) | (0x07 << 16)
 
@@ -350,6 +346,7 @@ const int MIDI_CHANS[16] = {
 #define PATCH_KEY_CHANNEL_MIDI_IN_KEYPRESS     "midi_in_keypress"
 #define PATCH_KEY_CHANNEL_MIDI_IN_KEYREL       "midi_in_keyrel"
 #define PATCH_KEY_CHANNEL_MIDI_IN_KILL         "midi_in_kill"
+#define PATCH_KEY_CHANNEL_MIDI_IN_ARM          "midi_in_arm"
 #define PATCH_KEY_CHANNEL_MIDI_IN_VOLUME       "midi_in_volume"
 #define PATCH_KEY_CHANNEL_MIDI_IN_MUTE         "midi_in_mute"
 #define PATCH_KEY_CHANNEL_MIDI_IN_SOLO         "midi_in_solo"
@@ -378,6 +375,7 @@ const int MIDI_CHANS[16] = {
 #define PATCH_KEY_PLUGIN_PATH                  "path"
 #define PATCH_KEY_PLUGIN_BYPASS                "bypass"
 #define PATCH_KEY_PLUGIN_PARAMS                "params"
+#define PATCH_KEY_PLUGIN_MIDI_IN_PARAMS        "midi_in_params"
 #define PATCH_KEY_COLUMN_INDEX                 "index"
 #define PATCH_KEY_COLUMN_WIDTH                 "width"
 #define PATCH_KEY_COLUMN_CHANNELS              "channels"
@@ -460,6 +458,10 @@ const int MIDI_CHANS[16] = {
 #define CONF_KEY_PLUGIN_CHOOSER_Y         "plugin_chooser_y"
 #define CONF_KEY_PLUGIN_CHOOSER_W         "plugin_chooser_w"
 #define CONF_KEY_PLUGIN_CHOOSER_H         "plugin_chooser_h"
+#define CONF_KEY_MIDI_INPUT_X             "midi_input_x"
+#define CONF_KEY_MIDI_INPUT_Y             "midi_input_y"
+#define CONF_KEY_MIDI_INPUT_W             "midi_input_w"
+#define CONF_KEY_MIDI_INPUT_H             "midi_input_h"
 #define CONF_KEY_PLUGIN_SORT_METHOD       "plugin_sort_method"
 
 /* JSON midimaps keys */
