@@ -785,6 +785,48 @@ const char *inputRecOff_xpm[] = {
 "                       ",
 "                       "};
 
+const char *inputToOutputOn_xpm[] = {
+"10 10 8 1",
+" 	c #4D4F4C",
+".	c #585A57",
+"+	c #666765",
+"@	c #6F716E",
+"#	c #939592",
+"$	c #999B98",
+"%	c #AEB0AD",
+"&	c #BCBEBB",
+"          ",
+"          ",
+" .#@      ",
+"  #&&#+   ",
+"    @$&%. ",
+"    @$&%. ",
+"  #&&#+   ",
+" .#@      ",
+"          ",
+"          "};
+
+const char *inputToOutputOff_xpm[] = {
+"10 10 8 1",
+" 	c #242523",
+".	c #2E302D",
+"+	c #3A3B39",
+"@	c #4F514E",
+"#	c #828481",
+"$	c #8B8D8A",
+"%	c #A7A9A6",
+"&	c #B9BBB7",
+"          ",
+"          ",
+" +$@      ",
+" .#&&#+   ",
+"    @$&%. ",
+"    @$&%. ",
+" .#&&#+   ",
+" +$@      ",
+"          ",
+"          "};
+
 const char *muteOff_xpm[] = {
 "18 18 8 1",
 " 	c #242523",
@@ -1512,7 +1554,7 @@ const char *fxRemoveOn_xpm[] = {
 #endif // #ifdef WITH_VST
 
 
-const char *beatsDivideOn_xpm[] = {
+const char *divideOn_xpm[] = {
 "18 18 7 1",
 " 	c #5A5A5A",
 ".	c #696969",
@@ -1541,7 +1583,7 @@ const char *beatsDivideOn_xpm[] = {
 "                  "};
 
 
-const char *beatsDivideOff_xpm[] = {
+const char *divideOff_xpm[] = {
 "18 18 8 1",
 " 	c #252525",
 ".	c #3B3B3B",
@@ -1571,7 +1613,7 @@ const char *beatsDivideOff_xpm[] = {
 "                  "};
 
 
-const char *beatsMultiplyOn_xpm[] = {
+const char *multiplyOn_xpm[] = {
 "18 18 8 1",
 " 	c #595B58",
 ".	c #737572",
@@ -1601,7 +1643,7 @@ const char *beatsMultiplyOn_xpm[] = {
 "                  "};
 
 
-const char *beatsMultiplyOff_xpm[] = {
+const char *multiplyOff_xpm[] = {
 "18 18 8 1",
 " 	c #242523",
 ".	c #4A4C49",
@@ -1690,3 +1732,63 @@ const char *channelPlay_xpm[] = {
 "                  ",
 "                  ",
 "                  "};
+
+
+const char *armOff_xpm[] = {
+"18 18 8 1",
+" 	c #242523",
+".	c #4F4445",
+"+	c #514647",
+"@	c #6D5C5E",
+"#	c #8E7372",
+"$	c #AA8889",
+"%	c #AC898A",
+"&	c #B18E8F",
+"                  ",
+"                  ",
+"                  ",
+"                  ",
+"      +#%%#.      ",
+"     @&&&&&&@     ",
+"    +&&&&&&&&.    ",
+"    #&&&&&&&&#    ",
+"    %&&&&&&&&%    ",
+"    %&&&&&&&&%    ",
+"    #&&&&&&&&#    ",
+"    .&&&&&&&&.    ",
+"     @&&&&&&@     ",
+"      .#%%#.      ",
+"                  ",
+"                  ",
+"                  ",
+"                  "};
+
+
+const char *armOn_xpm[] = {
+"18 18 8 1",
+" 	c #4D4F4C",
+".	c #6B5077",
+"+	c #805191",
+"@	c #9950AD",
+"#	c #9751B3",
+"$	c #9553AD",
+"%	c #AA52C9",
+"&	c #AE52D1",
+"                  ",
+"                  ",
+"                  ",
+"                  ",
+"      .#%%#.      ",
+"     +&&&&&&+     ",
+"    .&&&&&&&&.    ",
+"    #&&&&&&&&@    ",
+"    %&&&&&&&&%    ",
+"    %&&&&&&&&%    ",
+"    #&&&&&&&&$    ",
+"    .&&&&&&&&.    ",
+"     +&&&&&&+     ",
+"      .@%%$.      ",
+"                  ",
+"                  ",
+"                  ",
+"                  "};
