@@ -29,14 +29,15 @@
 
 #include <ctime>
 #include "../utils/log.h"
-#include "../utils/utils.h"
-#include "../utils/gui_utils.h"
+#include "../utils/fs.h"
+#include "../utils/gui.h"
 #include "../gui/dialogs/gd_mainWindow.h"
 #include "../gui/dialogs/gd_warnings.h"
 #include "init.h"
 #include "mixer.h"
 #include "wave.h"
 #include "const.h"
+#include "channel.h"
 #include "mixerHandler.h"
 #include "patch_DEPR_.h"
 #include "patch.h"
@@ -47,14 +48,17 @@
 #include "kernelMidi.h"
 
 
+extern KernelAudio   G_KernelAudio;
 extern Mixer 			   G_Mixer;
+extern Recorder  	   G_Recorder;
+extern KernelMidi    G_KernelMidi;
 extern bool		 		   G_audio_status;
 extern bool		 		   G_quit;
 extern Patch_DEPR_   G_Patch_DEPR_;
 extern Patch         G_Patch;
 extern Conf          G_Conf;
 extern MidiMapConf   G_MidiMap;
-extern gdMainWindow *mainWin;
+extern gdMainWindow *G_MainWin;
 
 #ifdef WITH_VST
 extern PluginHost G_PluginHost;
@@ -65,24 +69,16 @@ void init_prepareParser()
 {
 	time_t t;
   time (&t);
-	gLog("[init] Giada " G_VERSION_STR " - %s", ctime(&t));
+	gu_log("[init] Giada " G_VERSION_STR " - %s", ctime(&t));
 
 	G_Conf.read();
 	G_Patch_DEPR_.setDefault();
 	G_Patch.init();
 
-#ifdef WITH_VST
+	if (!gu_logInit(G_Conf.logMode))
+		gu_log("[init] log init failed! Using default stdout\n");
 
-	G_PluginHost.init(G_Conf.buffersize, G_Conf.samplerate);
-	G_PluginHost.sortPlugins(G_Conf.pluginSortMethod);
-
-#endif
-
-
-	if (!gLog_init(G_Conf.logMode))
-		gLog("[init] log init failed! Using default stdout\n");
-
-	gLog("[init] configuration file ready\n");
+	gu_log("[init] configuration file ready\n");
 }
 
 
@@ -91,16 +87,25 @@ void init_prepareParser()
 
 void init_prepareKernelAudio()
 {
-	kernelAudio::openDevice(
-		G_Conf.soundSystem,
-		G_Conf.soundDeviceOut,
-		G_Conf.soundDeviceIn,
-		G_Conf.channelsOut,
-		G_Conf.channelsIn,
-		G_Conf.samplerate,
-		G_Conf.buffersize);
+	G_KernelAudio.openDevice(G_Conf.soundSystem, G_Conf.soundDeviceOut,
+		G_Conf.soundDeviceIn,	G_Conf.channelsOut, G_Conf.channelsIn,
+		G_Conf.samplerate, G_Conf.buffersize);
 	G_Mixer.init();
-	recorder::init();
+	G_Recorder.init();
+
+#ifdef WITH_VST
+
+	/* If with Jack don't use buffer size stored in Conf. Use real buffersize
+	from the soundcard (G_KernelAudio.realBufsize). */
+
+	if (G_Conf.soundSystem == SYS_API_JACK)
+		G_PluginHost.init(G_KernelAudio.realBufsize, G_Conf.samplerate);
+	else
+		G_PluginHost.init(G_Conf.buffersize, G_Conf.samplerate);
+
+	G_PluginHost.sortPlugins(G_Conf.pluginSortMethod);
+
+#endif
 }
 
 
@@ -109,9 +114,9 @@ void init_prepareKernelAudio()
 
 void init_prepareKernelMIDI()
 {
-	kernelMidi::setApi(G_Conf.midiSystem);
-	kernelMidi::openOutDevice(G_Conf.midiPortOut);
-	kernelMidi::openInDevice(G_Conf.midiPortIn);
+	G_KernelMidi.setApi(G_Conf.midiSystem);
+	G_KernelMidi.openOutDevice(G_Conf.midiPortOut);
+	G_KernelMidi.openInDevice(G_Conf.midiPortIn);
 }
 
 
@@ -128,9 +133,9 @@ void init_prepareMidiMap()
 	// TODO - do the opposite: if json fails, go with deprecated one
 
 	if (G_MidiMap.read(G_Conf.midiMapPath) != MIDIMAP_READ_OK) {
-		gLog("[init_prepareMidiMap] JSON-based midimap read failed, trying with the deprecated one...\n");
+		gu_log("[init_prepareMidiMap] JSON-based midimap read failed, trying with the deprecated one...\n");
 		if (G_MidiMap.readMap_DEPR_(G_Conf.midiMapPath) == MIDIMAP_INVALID)
-			gLog("[init_prepareMidiMap] unable to read deprecated midimap. Nothing to do\n");
+			gu_log("[init_prepareMidiMap] unable to read deprecated midimap. Nothing to do\n");
 		}
 }
 
@@ -140,25 +145,20 @@ void init_prepareMidiMap()
 
 void init_startGUI(int argc, char **argv)
 {
-	char win_label[32];
-	sprintf(win_label, "%s - %s",
-					G_APP_NAME,
-					!strcmp(G_Patch_DEPR_.name, "") ? "(default patch)" : G_Patch_DEPR_.name);
+	G_MainWin = new gdMainWindow(GUI_WIDTH, GUI_HEIGHT, "", argc, argv);
+	G_MainWin->resize(G_Conf.mainWindowX, G_Conf.mainWindowY, G_Conf.mainWindowW,
+    G_Conf.mainWindowH);
 
-	mainWin = new gdMainWindow(GUI_WIDTH, GUI_HEIGHT, win_label, argc, argv);
-	mainWin->resize(G_Conf.mainWindowX, G_Conf.mainWindowY, G_Conf.mainWindowW, G_Conf.mainWindowH);
+  gu_updateMainWinLabel(G_Patch.name == "" ? G_DEFAULT_PATCH_NAME : G_Patch.name);
 
 	/* never update the GUI elements if G_audio_status is bad, segfaults
 	 * are around the corner */
 
 	if (G_audio_status)
 		gu_updateControls();
-
-	if (!G_audio_status)
-		gdAlert(
-			"Your soundcard isn't configured correctly.\n"
-			"Check the configuration and restart Giada."
-		);
+  else
+		gdAlert("Your soundcard isn't configured correctly.\n"
+			"Check the configuration and restart Giada.");
 }
 
 /* -------------------------------------------------------------------------- */
@@ -167,7 +167,7 @@ void init_startGUI(int argc, char **argv)
 void init_startKernelAudio()
 {
 	if (G_audio_status)
-		kernelAudio::startStream();
+		G_KernelAudio.startStream();
 }
 
 
@@ -180,41 +180,47 @@ void init_shutdown()
 
 	/* store position and size of the main window for the next startup */
 
-	G_Conf.mainWindowX = mainWin->x();
-	G_Conf.mainWindowY = mainWin->y();
-	G_Conf.mainWindowW = mainWin->w();
-	G_Conf.mainWindowH = mainWin->h();
+	G_Conf.mainWindowX = G_MainWin->x();
+	G_Conf.mainWindowY = G_MainWin->y();
+	G_Conf.mainWindowW = G_MainWin->w();
+	G_Conf.mainWindowH = G_MainWin->h();
 
 	/* close any open subwindow, especially before cleaning PluginHost_DEPR_ to
 	 * avoid mess */
 
 	gu_closeAllSubwindows();
-	gLog("[init] all subwindows closed\n");
+	gu_log("[init] all subwindows closed\n");
 
 	/* write configuration file */
 
 	if (!G_Conf.write())
-		gLog("[init] error while saving configuration file!\n");
+		gu_log("[init] error while saving configuration file!\n");
 	else
-		gLog("[init] configuration saved\n");
+		gu_log("[init] configuration saved\n");
 
 	/* if G_audio_status we close the kernelAudio FIRST, THEN the mixer.
 	 * The opposite could cause random segfaults (even now with RtAudio?). */
 
 	if (G_audio_status) {
-		kernelAudio::closeDevice();
+		G_KernelAudio.closeDevice();
 		G_Mixer.close();
-		gLog("[init] Mixer closed\n");
+		gu_log("[init] Mixer closed\n");
 	}
 
-	recorder::clearAll();
-	gLog("[init] Recorder cleaned up\n");
+	G_Recorder.clearAll();
+  for (unsigned i=0; i<G_Mixer.channels.size(); i++) {
+		G_Mixer.channels.at(i)->hasActions  = false;
+		G_Mixer.channels.at(i)->readActions = false;
+		//if (G_Mixer.channels.at(i)->type == CHANNEL_SAMPLE)
+		//	((SampleChannel*)G_Mixer.channels.at(i))->readActions = false;
+	}
+	gu_log("[init] Recorder cleaned up\n");
 
 #ifdef WITH_VST
 	G_PluginHost.freeAllStacks(&G_Mixer.channels, &G_Mixer.mutex_plugins);
-	gLog("[init] PluginHost cleaned up\n");
+	gu_log("[init] PluginHost cleaned up\n");
 #endif
 
-	gLog("[init] Giada " G_VERSION_STR " closed\n\n");
-	gLog_close();
+	gu_log("[init] Giada " G_VERSION_STR " closed\n\n");
+	gu_logClose();
 }
