@@ -27,11 +27,7 @@
  * -------------------------------------------------------------------------- */
 
 
-#include <math.h>
 #include "../utils/log.h"
-#include "../utils/gui_utils.h"
-#include "mixer.h"
-#include "init.h"
 #include "wave.h"
 #include "recorder.h"
 #include "pluginHost.h"
@@ -42,9 +38,13 @@
 #include "sampleChannel.h"
 #include "midiChannel.h"
 #include "kernelMidi.h"
+#include "mixer.h"
 
 
+extern KernelAudio G_KernelAudio;
 extern Mixer 			 G_Mixer;
+extern Recorder    G_Recorder;
+extern KernelMidi  G_KernelMidi;
 extern MidiMapConf G_MidiMap;
 extern Patch_DEPR_ G_Patch_DEPR_;
 extern Conf				 G_Conf;
@@ -62,12 +62,6 @@ Mixer::Mixer()
 /* -------------------------------------------------------------------------- */
 
 
-Mixer::~Mixer() {}
-
-
-/* -------------------------------------------------------------------------- */
-
-
 #define TICKSIZE 38
 
 
@@ -102,9 +96,10 @@ void Mixer::init()
 	docross     = false;
 	rewindWait  = false;
 	running     = false;
+	recording   = false;
 	ready       = true;
 	waitRec     = 0;
-	actualFrame = 0;
+	currentFrame = 0;
 	bpm 		    = DEFAULT_BPM;
 	bars		    = DEFAULT_BARS;
 	beats		    = DEFAULT_BEATS;
@@ -120,7 +115,6 @@ void Mixer::init()
 	inVol        = DEFAULT_IN_VOL;
 	peakOut      = 0.0f;
 	peakIn	     = 0.0f;
-	chanInput    = NULL;
 	inputTracker = 0;
 
 	actualBeat    = 0;
@@ -137,7 +131,7 @@ void Mixer::init()
 	/** TODO - set kernelAudio::realBufsize * 2 as private member */
 
 	vChanInput   = NULL;
-	vChanInToOut = (float *) malloc(kernelAudio::realBufsize * 2 * sizeof(float));
+	vChanInToOut = (float *) malloc(G_KernelAudio.realBufsize * 2 * sizeof(float));
 
 	pthread_mutex_init(&mutex_recs, NULL);
 	pthread_mutex_init(&mutex_chans, NULL);
@@ -154,7 +148,7 @@ void Mixer::init()
 Channel *Mixer::addChannel(int type)
 {
 	Channel *ch;
-	int bufferSize = kernelAudio::realBufsize*2;
+	int bufferSize = G_KernelAudio.realBufsize * 2;
 
 	if (type == CHANNEL_SAMPLE)
 		ch = new SampleChannel(bufferSize, &G_MidiMap);
@@ -175,7 +169,7 @@ Channel *Mixer::addChannel(int type)
 	}
 
 	ch->index = getNewIndex();
-	gLog("[mixer] channel index=%d added, type=%d, total=%d\n", ch->index, ch->type, channels.size());
+	gu_log("[mixer] channel index=%d added, type=%d, total=%d\n", ch->index, ch->type, channels.size());
 	return ch;
 }
 
@@ -214,7 +208,7 @@ int Mixer::deleteChannel(Channel *ch)
 	}
 
 	if (index == -1) {
-		gLog("[Mixer::deleteChannel] unable to find Channel %d for deletion!\n", ch->index);
+		gu_log("[Mixer::deleteChannel] unable to find Channel %d for deletion!\n", ch->index);
 		return 0;
 	}
 
@@ -228,7 +222,7 @@ int Mixer::deleteChannel(Channel *ch)
 			return 1;
 		}
 		//else
-		//	gLog("[mixer::deleteChannel] waiting for mutex...\n");
+		//	gu_log("[mixer::deleteChannel] waiting for mutex...\n");
 	}
 }
 
@@ -241,7 +235,7 @@ Channel *Mixer::getChannelByIndex(int index)
 	for (unsigned i=0; i<channels.size(); i++)
 		if (channels.at(i)->index == index)
 			return channels.at(i);
-	gLog("[mixer::getChannelByIndex] channel at index %d not found!\n", index);
+	gu_log("[mixer::getChannelByIndex] channel at index %d not found!\n", index);
 	return NULL;
 }
 
@@ -252,8 +246,8 @@ Channel *Mixer::getChannelByIndex(int index)
 void Mixer::sendMIDIsync()
 {
 	if (G_Conf.midiSync == MIDI_SYNC_CLOCK_M) {
-		if (actualFrame % (framesPerBeat/24) == 0)
-			kernelMidi::send(MIDI_CLOCK, -1, -1);
+		if (currentFrame % (framesPerBeat/24) == 0)
+			G_KernelMidi.send(MIDI_CLOCK, -1, -1);
 	}
 	else
 	if (G_Conf.midiSync == MIDI_SYNC_MTC_M) {
@@ -263,7 +257,7 @@ void Mixer::sendMIDIsync()
 		 * 1-4 and 5-8. We check timecode frame's parity: if even, send
 		 * range 1-4, if odd send 5-8. */
 
-		if (actualFrame % midiTCrate == 0) {
+		if (currentFrame % midiTCrate == 0) {
 
 			/* frame low nibble
 			 * frame high nibble
@@ -271,10 +265,10 @@ void Mixer::sendMIDIsync()
 			 * seconds high nibble */
 
 			if (midiTCframes % 2 == 0) {
-				kernelMidi::send(MIDI_MTC_QUARTER, (midiTCframes & 0x0F)  | 0x00, -1);
-				kernelMidi::send(MIDI_MTC_QUARTER, (midiTCframes >> 4)    | 0x10, -1);
-				kernelMidi::send(MIDI_MTC_QUARTER, (midiTCseconds & 0x0F) | 0x20, -1);
-				kernelMidi::send(MIDI_MTC_QUARTER, (midiTCseconds >> 4)   | 0x30, -1);
+				G_KernelMidi.send(MIDI_MTC_QUARTER, (midiTCframes & 0x0F)  | 0x00, -1);
+				G_KernelMidi.send(MIDI_MTC_QUARTER, (midiTCframes >> 4)    | 0x10, -1);
+				G_KernelMidi.send(MIDI_MTC_QUARTER, (midiTCseconds & 0x0F) | 0x20, -1);
+				G_KernelMidi.send(MIDI_MTC_QUARTER, (midiTCseconds >> 4)   | 0x30, -1);
 			}
 
 			/* minutes low nibble
@@ -283,10 +277,10 @@ void Mixer::sendMIDIsync()
 			 * hours high nibble SMPTE frame rate */
 
 			else {
-				kernelMidi::send(MIDI_MTC_QUARTER, (midiTCminutes & 0x0F) | 0x40, -1);
-				kernelMidi::send(MIDI_MTC_QUARTER, (midiTCminutes >> 4)   | 0x50, -1);
-				kernelMidi::send(MIDI_MTC_QUARTER, (midiTChours & 0x0F)   | 0x60, -1);
-				kernelMidi::send(MIDI_MTC_QUARTER, (midiTChours >> 4)     | 0x70, -1);
+				G_KernelMidi.send(MIDI_MTC_QUARTER, (midiTCminutes & 0x0F) | 0x40, -1);
+				G_KernelMidi.send(MIDI_MTC_QUARTER, (midiTCminutes >> 4)   | 0x50, -1);
+				G_KernelMidi.send(MIDI_MTC_QUARTER, (midiTChours & 0x0F)   | 0x60, -1);
+				G_KernelMidi.send(MIDI_MTC_QUARTER, (midiTChours >> 4)     | 0x70, -1);
 			}
 
 			midiTCframes++;
@@ -305,7 +299,7 @@ void Mixer::sendMIDIsync()
 						midiTCminutes = 0;
 					}
 				}
-				//gLog("%d:%d:%d:%d\n", midiTChours, midiTCminutes, midiTCseconds, midiTCframes);
+				//gu_log("%d:%d:%d:%d\n", midiTChours, midiTCminutes, midiTCseconds, midiTCframes);
 			}
 		}
 	}
@@ -328,250 +322,64 @@ void Mixer::sendMIDIrewind()
 	 * SMPTE time in one message */
 
 	if (G_Conf.midiSync == MIDI_SYNC_MTC_M) {
-		kernelMidi::send(MIDI_SYSEX, 0x7F, 0x00);  // send msg on channel 0
-		kernelMidi::send(0x01, 0x01, 0x00);        // hours 0
-		kernelMidi::send(0x00, 0x00, 0x00);        // mins, secs, frames 0
-		kernelMidi::send(MIDI_EOX, -1, -1);        // end of sysex
+		G_KernelMidi.send(MIDI_SYSEX, 0x7F, 0x00);  // send msg on channel 0
+		G_KernelMidi.send(0x01, 0x01, 0x00);        // hours 0
+		G_KernelMidi.send(0x00, 0x00, 0x00);        // mins, secs, frames 0
+		G_KernelMidi.send(MIDI_EOX, -1, -1);        // end of sysex
 	}
 }
 
 /* -------------------------------------------------------------------------- */
 
 
-int Mixer::masterPlay(
-	void *out_buf, void *in_buf, unsigned n_frames,
+int Mixer::masterPlay(void *outBuf, void *inBuf, unsigned bufferSize,
 	double streamTime, RtAudioStreamStatus status, void *userData)
 {
-	return G_Mixer.__masterPlay(out_buf, in_buf, n_frames);
+	return G_Mixer.__masterPlay(outBuf, inBuf, bufferSize);
 }
 
 
 /* -------------------------------------------------------------------------- */
 
 
-int Mixer::__masterPlay(void *out_buf, void *in_buf, unsigned bufferFrames)
+int Mixer::__masterPlay(void *_outBuf, void *_inBuf, unsigned bufferSize)
 {
 	if (!ready)
 		return 0;
 
-	float *outBuf = ((float *) out_buf);
-	float *inBuf  = ((float *) in_buf);
-	bufferFrames *= 2;     // stereo
+	float *outBuf = (float *) _outBuf;
+	float *inBuf  = G_KernelAudio.inputEnabled ? (float *) _inBuf : nullptr;
+	bufferSize   *= 2;     // stereo
 	peakOut       = 0.0f;  // reset peak calculator
 	peakIn        = 0.0f;  // reset peak calculator
 
-	/* always clean each buffer */
-
-	memset(outBuf, 0, sizeof(float) * bufferFrames);         // out
-	memset(vChanInToOut, 0, sizeof(float) * bufferFrames);   // inToOut vChan
-
-	pthread_mutex_lock(&mutex_chans);
-	for (unsigned i=0; i<channels.size(); i++)
-		if (channels.at(i)->type == CHANNEL_SAMPLE)
-			((SampleChannel*)channels.at(i))->clear();
-	pthread_mutex_unlock(&mutex_chans);
-
-	for (unsigned j=0; j<bufferFrames; j+=2) {
-
-		if (kernelAudio::inputEnabled) {
-
-			/* input peak calculation (left chan only so far). */
-
-			if (inBuf[j] * inVol > peakIn)
-				peakIn = inBuf[j] * inVol;
-
-			/* "hear what you're playing" - process, copy and paste the input buffer
-			 * onto the output buffer */
-
-			if (inToOut) {
-				vChanInToOut[j]   = inBuf[j]   * inVol;
-				vChanInToOut[j+1] = inBuf[j+1] * inVol;
-			}
-		}
-
-		/* operations to do if the sequencer is running:
-		 * - compute quantizer
-		 * - time check for LOOP_REPEAT
-		 * - reset loops at beat 0
-		 * - read recorded actions
-		 * - reset actualFrame */
+	clearAllBuffers(outBuf, bufferSize);
 
+	for (unsigned j=0; j<bufferSize; j+=2) {
+		processLineIn(inBuf, j);
 		if (running) {
-
-			/* line in recording */
-
-			if (chanInput != NULL && kernelAudio::inputEnabled) {
-
-				/* delay comp: wait until waitRec reaches delayComp. WaitRec
-				 * returns to 0 in mixerHandler, as soon as the recording ends */
-
-				if (waitRec < G_Conf.delayComp)
-					waitRec += 2;
-				else {
-					vChanInput[inputTracker]   += inBuf[j]   * inVol;
-					vChanInput[inputTracker+1] += inBuf[j+1] * inVol;
-					inputTracker += 2;
-					if (inputTracker >= totalFrames)
-						inputTracker = 0;
-				}
-			}
-
-			/* quantizer computations: quantize rewind and all channels. */
-
-			if (quantize > 0 && quanto > 0) {
-				if (actualFrame % (quanto) == 0) {   // is quanto!
-					if (rewindWait) {
-						rewindWait = false;
-						rewind();
-					}
-					pthread_mutex_lock(&mutex_chans);
-					for (unsigned k=0; k<channels.size(); k++)
-						channels.at(k)->quantize(k, j, actualFrame);  // j == localFrame
-					pthread_mutex_unlock(&mutex_chans);
-				}
-			}
-
-			/* reset LOOP_REPEAT, if a bar has passed */
-
-			if (actualFrame % framesPerBar == 0 && actualFrame != 0) {
-				if (metronome)
-					tickPlay = true;
-
-				pthread_mutex_lock(&mutex_chans);
-				for (unsigned k=0; k<channels.size(); k++)
-					channels.at(k)->onBar(j);
-				pthread_mutex_unlock(&mutex_chans);
-			}
-
-			/* reset loops on beat 0 */
-
-			if (actualFrame == 0) {
-				pthread_mutex_lock(&mutex_chans);
-				for (unsigned k=0; k<channels.size(); k++)
-					channels.at(k)->onZero(j, G_Conf.recsStopOnChanHalt);
-				pthread_mutex_unlock(&mutex_chans);
-			}
-
-			/* reading all actions recorded */
-
-			pthread_mutex_lock(&mutex_recs);
-			for (unsigned y=0; y<recorder::frames.size(); y++) {
-				if (recorder::frames.at(y) == actualFrame) {
-					for (unsigned z=0; z<recorder::global.at(y).size(); z++) {
-						int index   = recorder::global.at(y).at(z)->chan;
-						Channel *ch = getChannelByIndex(index);
-						ch->parseAction(recorder::global.at(y).at(z), j, actualFrame, quantize, running);
-					}
-					break;
-				}
-			}
-			pthread_mutex_unlock(&mutex_recs);
-
-			/* increase actualFrame */
-
-			actualFrame += 2;
-
-			/* if actualFrame > totalFrames the sequencer returns to frame 0,
-			 * beat 0. This must be the last operation. */
-
-			if (actualFrame > totalFrames) {
-				actualFrame = 0;
-				actualBeat  = 0;
-			}
-			else
-			if (actualFrame % framesPerBeat == 0 && actualFrame > 0) {
-				actualBeat++;
-
-				/* avoid tick and tock to overlap when a new bar has passed (which
-				 * is also a beat) */
-
-				if (metronome && !tickPlay)
-					tockPlay = true;
-			}
-
+			lineInRec(inBuf, j);
+			doQuantize(j);
+			testBar(j);
+			testFirstBeat(j);
+			readActions(j);
+			currentFrame += 2;
+			testLastBeat();  // this test must be the last one
 			sendMIDIsync();
-
-		} // if (running)
-
-		/* sum channels, CHANNEL_SAMPLE only */
-
-		pthread_mutex_lock(&mutex_chans);
-		for (unsigned k=0; k<channels.size(); k++) {
-			if (channels.at(k)->type == CHANNEL_SAMPLE)
-				((SampleChannel*)channels.at(k))->sum(j, running);
 		}
-		pthread_mutex_unlock(&mutex_chans);
+		sumChannels(j);
+	}
 
-		/* metronome play */
-		/** FIXME - move this one after the peak meter calculation */
+	renderIO(outBuf, inBuf);
 
-		if (tockPlay) {
-			outBuf[j]   += tock[tockTracker];
-			outBuf[j+1] += tock[tockTracker];
-			tockTracker++;
-			if (tockTracker >= TICKSIZE-1) {
-				tockPlay    = false;
-				tockTracker = 0;
-			}
-		}
-		if (tickPlay) {
-			outBuf[j]   += tick[tickTracker];
-			outBuf[j+1] += tick[tickTracker];
-			tickTracker++;
-			if (tickTracker >= TICKSIZE-1) {
-				tickPlay    = false;
-				tickTracker = 0;
-			}
-		}
-	} // end loop J
+	/* post processing */
 
-
-	/* final loop: sum virtual channels and process plugins. */
-
-	pthread_mutex_lock(&mutex_chans);
-	for (unsigned k=0; k<channels.size(); k++)
-		channels.at(k)->process(outBuf);
-	pthread_mutex_unlock(&mutex_chans);
-
-	/* processing fxs master in & out, if any. */
-
-#ifdef WITH_VST
-	pthread_mutex_lock(&mutex_plugins);
-	G_PluginHost.processStack(outBuf, PluginHost::MASTER_OUT);
-	G_PluginHost.processStack(vChanInToOut, PluginHost::MASTER_IN);
-	pthread_mutex_unlock(&mutex_plugins);
-#endif
-
-	/* post processing master fx + peak calculation. */
-
-	for (unsigned j=0; j<bufferFrames; j+=2) {
-
-		/* merging vChanInToOut, if enabled */
-
-		if (inToOut) {
-			outBuf[j]   += vChanInToOut[j];
-			outBuf[j+1] += vChanInToOut[j+1];
-		}
-
-		outBuf[j]   *= outVol;
-		outBuf[j+1] *= outVol;
-
-		/* computes the peak for the left channel (so far). */
-
-		if (outBuf[j] > peakOut)
-			peakOut = outBuf[j];
-
-		if (G_Conf.limitOutput) {
-			if (outBuf[j] > 1.0f)
-				outBuf[j] = 1.0f;
-			else if (outBuf[j] < -1.0f)
-				outBuf[j] = -1.0f;
-
-			if (outBuf[j+1] > 1.0f)
-				outBuf[j+1] = 1.0f;
-			else if (outBuf[j+1] < -1.0f)
-				outBuf[j+1] = -1.0f;
-		}
+	for (unsigned j=0; j<bufferSize; j+=2) {
+		finalizeOutput(outBuf, j);
+		if (G_Conf.limitOutput)
+			limitOutput(outBuf, j);
+		computePeak(outBuf, j);
+		renderMetronome(outBuf, j);
 	}
 
 	return 0;
@@ -613,7 +421,7 @@ void Mixer::updateFrameBars()
 		free(vChanInput);
 	vChanInput = (float*) malloc(totalFrames * sizeof(float));
 	if (!vChanInput)
-		gLog("[Mixer] vChanInput realloc error!\n");
+		gu_log("[Mixer] vChanInput realloc error!\n");
 }
 
 
@@ -655,7 +463,7 @@ bool Mixer::isSilent()
 
 void Mixer::rewind()
 {
-	actualFrame = 0;
+	currentFrame = 0;
 	actualBeat  = 0;
 
 	if (running)
@@ -711,19 +519,279 @@ bool Mixer::hasEditedSamples()
 /* -------------------------------------------------------------------------- */
 
 
-bool Mixer::mergeVirtualInput()
+void Mixer::mergeVirtualInput()
 {
-	if (vChanInput == NULL) {
-		gLog("[Mixer] virtual input channel not alloc'd\n");
-		return false;
+	for (unsigned i=0; i<channels.size(); i++) {
+		if (channels.at(i)->type == CHANNEL_MIDI)
+			continue;
+		SampleChannel *ch = (SampleChannel*) channels.at(i);
+		if (ch->armed)
+			memcpy(ch->wave->data, vChanInput, totalFrames * sizeof(float));
 	}
-	else {
-#ifdef WITH_VST
-		G_PluginHost.processStackOffline(vChanInput, PluginHost::MASTER_IN, 0, totalFrames);
-#endif
-		int numFrames = totalFrames*sizeof(float);
-		memcpy(chanInput->wave->data, vChanInput, numFrames);
-		memset(vChanInput, 0, numFrames); // clear vchan
-		return true;
+	memset(vChanInput, 0, totalFrames * sizeof(float)); // clear vchan
+}
+
+
+/* -------------------------------------------------------------------------- */
+
+
+void Mixer::lineInRec(float *inBuf, unsigned frame)
+{
+	if (!mh_hasArmedSampleChannels() || !G_KernelAudio.inputEnabled || !recording)
+	 	return;
+
+	/* Delay comp: wait until waitRec reaches delayComp. WaitRec
+	 * returns to 0 in mixerHandler, as soon as the recording ends */
+
+	if (waitRec < G_Conf.delayComp) {
+		waitRec += 2;
+		return;
+	}
+
+	vChanInput[inputTracker]   += inBuf[frame]   * inVol;
+	vChanInput[inputTracker+1] += inBuf[frame+1] * inVol;
+	inputTracker += 2;
+	if (inputTracker >= totalFrames)
+		inputTracker = 0;
+}
+
+
+/* -------------------------------------------------------------------------- */
+
+
+void Mixer::processLineIn(float *inBuf, unsigned frame)
+{
+	if (!G_KernelAudio.inputEnabled)
+		return;
+
+	/* input peak calculation (left chan only so far). */
+
+	if (inBuf[frame] * inVol > peakIn)
+		peakIn = inBuf[frame] * inVol;
+
+	/* "hear what you're playing" - process, copy and paste the input buffer
+	 * onto the output buffer */
+
+	if (inToOut) {
+		vChanInToOut[frame]   = inBuf[frame]   * inVol;
+		vChanInToOut[frame+1] = inBuf[frame+1] * inVol;
 	}
 }
+
+
+/* -------------------------------------------------------------------------- */
+
+
+void Mixer::readActions(unsigned frame)
+{
+	pthread_mutex_lock(&mutex_recs);
+	for (unsigned i=0; i<G_Recorder.frames.size(); i++) {
+		if (G_Recorder.frames.at(i) == currentFrame) {
+			for (unsigned j=0; j<G_Recorder.global.at(i).size(); j++) {
+				int index   = G_Recorder.global.at(i).at(j)->chan;
+				Channel *ch = getChannelByIndex(index);
+				ch->parseAction(G_Recorder.global.at(i).at(j), frame, currentFrame, quantize, running);
+			}
+			break;
+		}
+	}
+	pthread_mutex_unlock(&mutex_recs);
+}
+
+
+/* -------------------------------------------------------------------------- */
+
+
+void Mixer::doQuantize(unsigned frame)
+{
+	if (quantize < 0 || quanto <= 0) // if quantizer disabled
+		return;
+	if (currentFrame % (quanto) != 0) // if a quanto has not passed yet
+		return;
+
+	if (rewindWait) {
+		rewindWait = false;
+		rewind();
+	}
+	pthread_mutex_lock(&mutex_chans);
+	for (unsigned i=0; i<channels.size(); i++)
+		channels.at(i)->quantize(i, frame, this);  // j == localFrame
+	pthread_mutex_unlock(&mutex_chans);
+}
+
+
+/* -------------------------------------------------------------------------- */
+
+
+void Mixer::testBar(unsigned frame)
+{
+	if (currentFrame % framesPerBar != 0 || currentFrame == 0)
+		return;
+
+	if (metronome)
+		tickPlay = true;
+
+	pthread_mutex_lock(&mutex_chans);
+	for (unsigned k=0; k<channels.size(); k++)
+		channels.at(k)->onBar(frame);
+	pthread_mutex_unlock(&mutex_chans);
+}
+
+
+/* -------------------------------------------------------------------------- */
+
+
+void Mixer::testFirstBeat(unsigned frame)
+{
+	if (currentFrame != 0)
+		return;
+	pthread_mutex_lock(&mutex_chans);
+	for (unsigned k=0; k<channels.size(); k++)
+		channels.at(k)->onZero(frame, G_Conf.recsStopOnChanHalt);
+	pthread_mutex_unlock(&mutex_chans);
+}
+
+
+/* -------------------------------------------------------------------------- */
+
+
+void Mixer::testLastBeat()
+{
+	/* if currentFrame > totalFrames the sequencer returns to frame 0,
+	 * beat 0. This must be the last operation. */
+
+	if (currentFrame > totalFrames) {
+		currentFrame = 0;
+		actualBeat  = 0;
+	}
+	else
+	if (currentFrame % framesPerBeat == 0 && currentFrame > 0) {
+		actualBeat++;
+
+		/* avoid tick and tock to overlap when a new bar has passed (which
+		 * is also a beat) */
+
+		if (metronome && !tickPlay)
+			tockPlay = true;
+	}
+}
+
+
+/* -------------------------------------------------------------------------- */
+
+
+void Mixer::sumChannels(unsigned frame)
+{
+	pthread_mutex_lock(&mutex_chans);
+	for (unsigned k=0; k<channels.size(); k++) {
+		if (channels.at(k)->type == CHANNEL_SAMPLE)
+			((SampleChannel*)channels.at(k))->sum(frame, running);
+	}
+	pthread_mutex_unlock(&mutex_chans);
+}
+
+
+/* -------------------------------------------------------------------------- */
+
+
+void Mixer::renderMetronome(float *outBuf, unsigned frame)
+{
+	if (tockPlay) {
+		outBuf[frame]   += tock[tockTracker];
+		outBuf[frame+1] += tock[tockTracker];
+		tockTracker++;
+		if (tockTracker >= TICKSIZE-1) {
+			tockPlay    = false;
+			tockTracker = 0;
+		}
+	}
+	if (tickPlay) {
+		outBuf[frame]   += tick[tickTracker];
+		outBuf[frame+1] += tick[tickTracker];
+		tickTracker++;
+		if (tickTracker >= TICKSIZE-1) {
+			tickPlay    = false;
+			tickTracker = 0;
+		}
+	}
+}
+
+
+/* -------------------------------------------------------------------------- */
+
+
+void Mixer::renderIO(float *outBuf, float *inBuf)
+{
+	pthread_mutex_lock(&mutex_chans);
+	for (unsigned k=0; k<channels.size(); k++)
+		channels.at(k)->process(outBuf, inBuf);
+	pthread_mutex_unlock(&mutex_chans);
+
+#ifdef WITH_VST
+	pthread_mutex_lock(&mutex_plugins);
+	G_PluginHost.processStack(outBuf, PluginHost::MASTER_OUT);
+	G_PluginHost.processStack(vChanInToOut, PluginHost::MASTER_IN);
+	pthread_mutex_unlock(&mutex_plugins);
+#endif
+}
+
+
+/* -------------------------------------------------------------------------- */
+
+
+void Mixer::computePeak(float *outBuf, unsigned frame)
+{
+	/* TODO it takes into account only left channel so far! */
+	if (outBuf[frame] > peakOut)
+		peakOut = outBuf[frame];
+}
+
+
+/* -------------------------------------------------------------------------- */
+
+
+void Mixer::limitOutput(float *outBuf, unsigned frame)
+{
+	if (outBuf[frame] > 1.0f)
+		outBuf[frame] = 1.0f;
+	else
+	if (outBuf[frame] < -1.0f)
+		outBuf[frame] = -1.0f;
+
+	if (outBuf[frame+1] > 1.0f)
+		outBuf[frame+1] = 1.0f;
+	else
+	if (outBuf[frame+1] < -1.0f)
+		outBuf[frame+1] = -1.0f;
+}
+
+
+/* -------------------------------------------------------------------------- */
+
+
+void Mixer::finalizeOutput(float *outBuf, unsigned frame)
+{
+	/* merge vChanInToOut, if enabled */
+
+	if (inToOut) {
+		outBuf[frame]   += vChanInToOut[frame];
+		outBuf[frame+1] += vChanInToOut[frame+1];
+	}
+	outBuf[frame]   *= outVol;
+	outBuf[frame+1] *= outVol;
+}
+
+
+/* -------------------------------------------------------------------------- */
+
+
+void Mixer::clearAllBuffers(float *outBuf, unsigned bufferSize)
+{
+	memset(outBuf, 0, sizeof(float) * bufferSize);         // out
+	memset(vChanInToOut, 0, sizeof(float) * bufferSize);   // inToOut vChan
+
+	pthread_mutex_lock(&mutex_chans);
+	for (unsigned i=0; i<channels.size(); i++)
+		channels.at(i)->clear();
+	pthread_mutex_unlock(&mutex_chans);
+}
