@@ -27,24 +27,16 @@
  * -------------------------------------------------------------------------- */
 
 
-#include <stdint.h>
 #include "../utils/log.h"
-#include "../utils/utils.h"
-#include "../gui/dialogs/gd_mainWindow.h"
-#include "../gui/elems/ge_keyboard.h"
-#include "patch.h"
+#include "../utils/string.h"
 #include "const.h"
-#include "init.h"
-#include "recorder.h"
 #include "conf.h"
-#include "wave.h"
 #include "mixer.h"
-#include "channel.h"
+#include "patch.h"
 
 
-extern Mixer 		     G_Mixer;
-extern Conf 		     G_Conf;
-extern gdMainWindow *mainWin;
+extern Mixer G_Mixer;
+extern Conf  G_Conf;
 
 
 void Patch::init()
@@ -77,7 +69,7 @@ int Patch::write(const string &file)
 #endif
 
   if (json_dump_file(jRoot, file.c_str(), JSON_COMPACT) != 0) {
-    gLog("[Patch::write] unable to write patch file!\n");
+    gu_log("[Patch::write] unable to write patch file!\n");
     return 0;
   }
   return 1;
@@ -91,7 +83,7 @@ int Patch::read(const string &file)
 {
   jRoot = json_load_file(file.c_str(), 0, &jError);
   if (!jRoot) {
-    gLog("[Patch::read] unable to read patch file! Error on line %d: %s\n", jError.line, jError.text);
+    gu_log("[Patch::read] unable to read patch file! Error on line %d: %s\n", jError.line, jError.text);
     return PATCH_UNREADABLE;
   }
 
@@ -127,17 +119,23 @@ void Patch::writePlugins(json_t *jContainer, vector<plugin_t> *plugins, const ch
   for (unsigned j=0; j<plugins->size(); j++) {
     json_t   *jPlugin = json_object();
     plugin_t  plugin  = plugins->at(j);
-    json_object_set_new(jPlugin, PATCH_KEY_PLUGIN_PATH,     json_string(plugin.path.c_str()));
-    json_object_set_new(jPlugin, PATCH_KEY_PLUGIN_BYPASS,   json_boolean(plugin.bypass));
+    json_object_set_new(jPlugin, PATCH_KEY_PLUGIN_PATH,   json_string(plugin.path.c_str()));
+    json_object_set_new(jPlugin, PATCH_KEY_PLUGIN_BYPASS, json_boolean(plugin.bypass));
     json_array_append_new(jPlugins, jPlugin);
 
     /* plugin params */
 
     json_t *jPluginParams = json_array();
-    for (unsigned z=0; z<plugin.params.size(); z++) {
+    for (unsigned z=0; z<plugin.params.size(); z++)
       json_array_append_new(jPluginParams, json_real(plugin.params.at(z)));
-    }
     json_object_set_new(jPlugin, PATCH_KEY_PLUGIN_PARAMS, jPluginParams);
+
+    /* midiIn params (midi learning on plugins' parameters) */
+
+    json_t *jPluginMidiInParams = json_array();
+    for (unsigned z=0; z<plugin.midiInParams.size(); z++)
+      json_array_append_new(jPluginMidiInParams, json_integer(plugin.midiInParams.at(z)));
+    json_object_set_new(jPlugin, PATCH_KEY_PLUGIN_MIDI_IN_PARAMS, jPluginMidiInParams);
   }
   json_object_set_new(jContainer, key, jPlugins);
 }
@@ -226,6 +224,7 @@ void Patch::writeChannels(json_t *jContainer, vector<channel_t> *channels)
     json_object_set_new(jChannel, PATCH_KEY_CHANNEL_MIDI_IN_KEYPRESS,     json_integer(channel.midiInKeyPress));
     json_object_set_new(jChannel, PATCH_KEY_CHANNEL_MIDI_IN_KEYREL,       json_integer(channel.midiInKeyRel));
     json_object_set_new(jChannel, PATCH_KEY_CHANNEL_MIDI_IN_KILL,         json_integer(channel.midiInKill));
+    json_object_set_new(jChannel, PATCH_KEY_CHANNEL_MIDI_IN_ARM,          json_integer(channel.midiInArm));
     json_object_set_new(jChannel, PATCH_KEY_CHANNEL_MIDI_IN_VOLUME,       json_integer(channel.midiInVolume));
     json_object_set_new(jChannel, PATCH_KEY_CHANNEL_MIDI_IN_MUTE,         json_integer(channel.midiInMute));
     json_object_set_new(jChannel, PATCH_KEY_CHANNEL_MIDI_IN_SOLO,         json_integer(channel.midiInSolo));
@@ -296,7 +295,7 @@ bool Patch::readColumns(json_t *jContainer)
   json_t *jColumn;
   json_array_foreach(jColumns, columnIndex, jColumn) {
 
-    string columnIndexStr = "column " + gItoa(columnIndex);
+    string columnIndexStr = "column " + gu_itoa(columnIndex);
     if (!checkObject(jColumn, columnIndexStr.c_str()))
       return 0;
 
@@ -323,7 +322,7 @@ bool Patch::readChannels(json_t *jContainer)
   json_t *jChannel;
   json_array_foreach(jChannels, channelIndex, jChannel) {
 
-    string channelIndexStr = "channel " + gItoa(channelIndex);
+    string channelIndexStr = "channel " + gu_itoa(channelIndex);
     if (!checkObject(jChannel, channelIndexStr.c_str()))
       return 0;
 
@@ -342,6 +341,7 @@ bool Patch::readChannels(json_t *jContainer)
     if (!setUint32(jChannel, PATCH_KEY_CHANNEL_MIDI_IN_KEYPRESS,     channel.midiInKeyPress)) return 0;
     if (!setUint32(jChannel, PATCH_KEY_CHANNEL_MIDI_IN_KEYREL,       channel.midiInKeyRel)) return 0;
     if (!setUint32(jChannel, PATCH_KEY_CHANNEL_MIDI_IN_KILL,         channel.midiInKill)) return 0;
+    if (!setUint32(jChannel, PATCH_KEY_CHANNEL_MIDI_IN_ARM,          channel.midiInArm)) return 0;
     if (!setUint32(jChannel, PATCH_KEY_CHANNEL_MIDI_IN_VOLUME,       channel.midiInVolume)) return 0;
     if (!setUint32(jChannel, PATCH_KEY_CHANNEL_MIDI_IN_MUTE,         channel.midiInMute)) return 0;
     if (!setUint32(jChannel, PATCH_KEY_CHANNEL_MIDI_IN_SOLO,         channel.midiInSolo)) return 0;
@@ -419,8 +419,8 @@ bool Patch::readPlugins(json_t *jContainer, vector<plugin_t> *container, const c
       return 0;
 
     plugin_t plugin;
-    if (!setString (jPlugin, PATCH_KEY_PLUGIN_PATH,   plugin.path)) return 0;
-    if (!setBool   (jPlugin, PATCH_KEY_PLUGIN_BYPASS, plugin.bypass)) return 0;
+    if (!setString(jPlugin, PATCH_KEY_PLUGIN_PATH,   plugin.path)) return 0;
+    if (!setBool  (jPlugin, PATCH_KEY_PLUGIN_BYPASS, plugin.bypass)) return 0;
 
     /* read plugin params */
 
@@ -432,6 +432,16 @@ bool Patch::readPlugins(json_t *jContainer, vector<plugin_t> *container, const c
     json_array_foreach(jParams, paramIndex, jParam)
       plugin.params.push_back(json_real_value(jParam));
 
+    /* read midiIn params (midi learning on plugins' parameters) */
+
+    json_t *jMidiInParams = json_object_get(jPlugin, PATCH_KEY_PLUGIN_MIDI_IN_PARAMS);
+    if (!checkArray(jMidiInParams, PATCH_KEY_PLUGIN_MIDI_IN_PARAMS)) return 0;
+
+    size_t midiInParamIndex;
+    json_t *jMidiInParam;
+    json_array_foreach(jMidiInParams, midiInParamIndex, jMidiInParam)
+      plugin.midiInParams.push_back(json_integer_value(jMidiInParam));
+      
     container->push_back(plugin);
   }
   return 1;
@@ -465,7 +475,7 @@ void Patch::sanitize()
     ch->panLeft  = ch->panLeft < 0.0f || ch->panLeft > 1.0f ? 1.0f : ch->panLeft;
     ch->panRight = ch->panRight < 0.0f || ch->panRight > 1.0f ? 1.0f : ch->panRight;
     ch->boost    = ch->boost < 1.0f ? DEFAULT_BOOST : ch->boost;
-    ch->pitch    = ch->pitch < 0.1f || ch->pitch > 4.0f ? gDEFAULT_PITCH : ch->pitch;
+    ch->pitch    = ch->pitch < 0.1f || ch->pitch > 4.0f ? G_DEFAULT_PITCH : ch->pitch;
   }
 }
 
