@@ -26,43 +26,32 @@
  *
  * -------------------------------------------------------------------------- */
 
+
 #ifdef WITH_VST
 
 #ifndef __PLUGIN_H__
 #define __PLUGIN_H__
 
 
-#include "../deps/juce/juce_audio_basics/juce_audio_basics.h"
-#include "../deps/juce/juce_audio_processors/juce_audio_processors.h"
-#include "../deps/juce/juce_core/juce_core.h"
-#include "../deps/juce/juce_data_structures/juce_data_structures.h"
-#include "../deps/juce/juce_events/juce_events.h"
-#include "../deps/juce/juce_graphics/juce_graphics.h"
-#include "../deps/juce/juce_gui_basics/juce_gui_basics.h"
-#include "../deps/juce/juce_gui_extra/juce_gui_extra.h"
+#include "../deps/juce-config.h"
 
 
-using std::string;
-
-
-class Plugin : public juce::AudioPluginInstance
+class Plugin
 {
 private:
 
-  juce::AudioProcessorEditor *ui;     // gui
-
   static int idGenerator;
-  int    id;
-  bool   bypass;
-  bool   status;
+
+  juce::AudioProcessorEditor *ui;     // gui
+  juce::AudioPluginInstance  *plugin; // core
+
+  int  id;
+  bool bypass;
 
 public:
 
-  /* initEditor
-   * Prepare plugin GUI. 'parent' is a void pointer to the parent window that
-   * will contain it. */
-
-  void initEditor();
+  Plugin(juce::AudioPluginInstance *p, double samplerate, int buffersize);
+  ~Plugin();
 
   void showEditor(void *parent);
 
@@ -78,19 +67,36 @@ public:
   /* getUniqueId
    * Return a string-based UID. */
 
-  string getUniqueId();
+  std::string getUniqueId();
 
-  inline void setId() { id = idGenerator++; }
-  inline int  getId() { return id; }
-  inline bool getStatus() { return status; }
-  inline bool isBypassed() { return bypass; }
-  inline int  getEditorW() { return ui->getWidth(); }
-  inline int  getEditorH() { return ui->getHeight(); }
+  std::string getName();
 
-  inline void toggleBypass() { bypass = !bypass; }
-  inline void setStatus(int s) { status = s; }
-  inline void setBypass(bool b) { bypass = b; }
+  bool  hasEditor();
+  int   getNumParameters();
+  float getParameter(int index);
+  void  setParameter(int index, float value);
+  std::string getParameterName(int index);
+  std::string getParameterText(int index);
+  std::string getParameterLabel(int index);
+  void  prepareToPlay(double samplerate, int buffersize);
+  bool  isSuspended();
+  void  process(juce::AudioBuffer<float> &b, juce::MidiBuffer &m);
+  int   getNumPrograms();
+  int   getCurrentProgram();
+  void  setCurrentProgram(int index);
+  std::string getProgramName(int index);
 
+  int  getId()           { return id; }
+  bool isBypassed()      { return bypass; }
+  int  getEditorW()      { return ui->getWidth(); }
+  int  getEditorH()      { return ui->getHeight(); }
+  void toggleBypass()    { bypass = !bypass; }
+  void setBypass(bool b) { bypass = b; }
+
+  /* midiInParams
+  A list of midiIn hex values for parameter automation. */
+
+  std::vector<uint32_t> midiInParams;
 };
 
 #endif
