@@ -29,20 +29,27 @@
 
 #include <math.h>
 #include "../utils/log.h"
+#include "../utils/string.h"
 #include "sampleChannel.h"
 #include "patch_DEPR_.h"
 #include "patch.h"
 #include "conf.h"
+#include "mixer.h"
 #include "wave.h"
 #include "pluginHost.h"
 #include "waveFx.h"
 #include "mixerHandler.h"
 #include "kernelMidi.h"
+#include "kernelAudio.h"
 
 
 using std::string;
 
 
+extern Recorder    G_Recorder;
+extern KernelAudio G_KernelAudio;
+
+
 SampleChannel::SampleChannel(int bufferSize, MidiMapConf *midiMapConf)
 	: Channel          (CHANNEL_SAMPLE, STATUS_EMPTY, bufferSize, midiMapConf),
 		frameRewind      (-1),
@@ -50,7 +57,7 @@ SampleChannel::SampleChannel(int bufferSize, MidiMapConf *midiMapConf)
 		tracker          (0),
 		begin            (0),
 		end              (0),
-		pitch            (gDEFAULT_PITCH),
+		pitch            (G_DEFAULT_PITCH),
 		boost            (1.0f),
 		mode             (DEFAULT_CHANMODE),
 		qWait	           (false),
@@ -60,12 +67,11 @@ SampleChannel::SampleChannel(int bufferSize, MidiMapConf *midiMapConf)
 		fadeoutVol       (1.0f),
 		fadeoutTracker   (0),
 		fadeoutStep      (DEFAULT_FADEOUT_STEP),
-	  readActions      (true),
 	  midiInReadActions(0x0),
 	  midiInPitch      (0x0)
 {
 	rsmp_state = src_new(SRC_LINEAR, 2, NULL);
-	pChan      = (float *) malloc(kernelAudio::realBufsize * 2 * sizeof(float));
+	pChan      = (float *) malloc(G_KernelAudio.realBufsize * 2 * sizeof(float));
 }
 
 
@@ -119,8 +125,8 @@ void SampleChannel::generateUniqueSampleName()
 {
 	string oldName = wave->name;
 	int k = 1; // Start from k = 1, zero is too nerdy
-	while (!mh_uniqueSamplename(this, wave->name.c_str())) {
-		wave->updateName((oldName + "-" + gItoa(k)).c_str());
+	while (!mh_uniqueSampleName(this, wave->name)) {
+		wave->updateName((oldName + "-" + gu_itoa(k)).c_str());
 		k++;
 	}
 }
@@ -140,7 +146,7 @@ void SampleChannel::clear()
 	if (status & (STATUS_PLAY | STATUS_ENDING)) {
 		tracker = fillChan(vChan, tracker, 0);
 		if (fadeoutOn && fadeoutType == XFADE) {
-			gLog("[clear] filling pChan fadeoutTracker=%d\n", fadeoutTracker);
+			gu_log("[clear] filling pChan fadeoutTracker=%d\n", fadeoutTracker);
 			fadeoutTracker = fillChan(pChan, fadeoutTracker, 0);
 		}
 	}
@@ -154,14 +160,14 @@ void SampleChannel::calcVolumeEnv(int frame)
 {
 	/* method: check this frame && next frame, then calculate delta */
 
-	recorder::action *a0 = NULL;
-	recorder::action *a1 = NULL;
+	Recorder::action *a0 = NULL;
+	Recorder::action *a1 = NULL;
 	int res;
 
 	/* get this action on frame 'frame'. It's unlikely that the action
 	 * is not found. */
 
-	res = recorder::getAction(index, ACTION_VOLUME, frame, &a0);
+	res = G_Recorder.getAction(index, ACTION_VOLUME, frame, &a0);
 	if (res == 0)
 		return;
 
@@ -170,10 +176,10 @@ void SampleChannel::calcVolumeEnv(int frame)
 	 * and use action at frame number 0 (actions[0]).
 	 * res == -2 ACTION_VOLUME not found. This should never happen */
 
-	res = recorder::getNextAction(index, ACTION_VOLUME, frame, &a1);
+	res = G_Recorder.getNextAction(index, ACTION_VOLUME, frame, &a1);
 
 	if (res == -1)
-		res = recorder::getAction(index, ACTION_VOLUME, 0, &a1);
+		res = G_Recorder.getAction(index, ACTION_VOLUME, 0, &a1);
 
 	volume_i = a0->fValue;
 	volume_d = ((a1->fValue - a0->fValue) / ((a1->frame - a0->frame) / 2)) * 1.003f;
@@ -278,7 +284,7 @@ void SampleChannel::rewind()
 /* -------------------------------------------------------------------------- */
 
 
-void SampleChannel::parseAction(recorder::action *a, int localFrame,
+void SampleChannel::parseAction(Recorder::action *a, int localFrame,
 		int globalFrame, int quantize, bool mixerIsRunning)
 {
 	if (readActions == false)
@@ -287,7 +293,7 @@ void SampleChannel::parseAction(recorder::action *a, int localFrame,
 	switch (a->type) {
 		case ACTION_KEYPRESS:
 			if (mode & SINGLE_ANY)
-				start(localFrame, false, quantize, mixerIsRunning);
+				start(localFrame, false, quantize, mixerIsRunning, false, false);
 			break;
 		case ACTION_KEYREL:
 			if (mode & SINGLE_ANY)
@@ -471,7 +477,7 @@ void SampleChannel::onZero(int frame, bool recsStopOnChanHalt)
 /* -------------------------------------------------------------------------- */
 
 
-void SampleChannel::quantize(int index, int localFrame, int globalFrame)
+void SampleChannel::quantize(int index, int localFrame, Mixer *mixer)
 {
 	/* skip if LOOP_ANY or not in quantizer-wait mode */
 
@@ -494,11 +500,15 @@ void SampleChannel::quantize(int index, int localFrame, int globalFrame)
 	/* this is the moment in which we record the keypress, if the
 	 * quantizer is on. SINGLE_PRESS needs overdub */
 
-	if (recorder::canRec(this)) {
-		if (mode == SINGLE_PRESS)
-			recorder::startOverdub(index, ACTION_KEYS, globalFrame);
+	if (G_Recorder.canRec(this, mixer)) {
+		if (mode == SINGLE_PRESS) {
+			G_Recorder.startOverdub(index, ACTION_KEYS, mixer->currentFrame,
+        G_KernelAudio.realBufsize);
+      readActions = false;   // don't read actions while overdubbing
+    }
 		else
-			recorder::rec(index, ACTION_KEYPRESS, globalFrame);
+			G_Recorder.rec(index, ACTION_KEYPRESS, mixer->currentFrame);
+    hasActions = true;
 	}
 }
 
@@ -603,13 +613,9 @@ void SampleChannel::calcFadeoutStep()
 
 void SampleChannel::setReadActions(bool v, bool recsStopOnChanHalt)
 {
-	if (v)
-		readActions = true;
-	else {
-		readActions = false;
-		if (recsStopOnChanHalt)
-			kill(0);  /// FIXME - wrong frame value
-	}
+	readActions = v;
+	if (!readActions && recsStopOnChanHalt)
+		kill(0);  /// FIXME - wrong frame value
 }
 
 
@@ -643,7 +649,7 @@ void SampleChannel::setFadeOut(int actionPostFadeout)
 
 void SampleChannel::setXFade(int frame)
 {
-	gLog("[xFade] frame=%d tracker=%d\n", frame, tracker);
+	gu_log("[xFade] frame=%d tracker=%d\n", frame, tracker);
 
 	calcFadeoutStep();
 	fadeoutOn      = true;
@@ -697,7 +703,7 @@ void SampleChannel::pushWave(Wave *w)
 {
 	wave   = w;
 	status = STATUS_OFF;
-	sendMidiLplay();
+	sendMidiLplay();     // FIXME - why here?!?!
 	begin  = 0;
 	end    = wave->size;
 }
@@ -712,14 +718,14 @@ bool SampleChannel::allocEmpty(int frames, int samplerate, int takeId)
 	if (!w->allocEmpty(frames, samplerate))
 		return false;
 
-	w->name     = "TAKE-" + gItoa(takeId);
-	w->pathfile = gGetCurrentPath() + G_SLASH + w->name;
+	w->name     = "TAKE-" + gu_itoa(takeId);
+	w->pathfile = gu_getCurrentPath() + G_SLASH + w->name;
 	wave        = w;
 	status      = STATUS_OFF;
 	begin       = 0;
 	end         = wave->size;
 
-	sendMidiLplay();
+	sendMidiLplay();  // FIXME - why here?!?!
 
 	return true;
 }
@@ -728,15 +734,24 @@ bool SampleChannel::allocEmpty(int frames, int samplerate, int takeId)
 /* -------------------------------------------------------------------------- */
 
 
-void SampleChannel::process(float *buffer)
+void SampleChannel::process(float *outBuffer, float *inBuffer)
 {
+	/* If armed and inbuffer is not null (i.e. input device available), copy input
+	buffer to vChan: this enables the live recording mode. The vChan will be
+	overwritten later by PluginHost::processStack, so that you would record "clean"
+	audio (i.e. not plugin-processed). */
+
+	if (armed && inBuffer)
+    for (int i=0; i<bufferSize; i++)
+      vChan[i] += inBuffer[i]; // add, don't overwrite (no raw memcpy)
+
 #ifdef WITH_VST
 	pluginHost->processStack(vChan, PluginHost::CHANNEL, this);
 #endif
 
 	for (int j=0; j<bufferSize; j+=2) {
-		buffer[j]   += vChan[j]   * volume * panLeft  * boost;
-		buffer[j+1] += vChan[j+1] * volume * panRight * boost;
+		outBuffer[j]   += vChan[j]   * volume * panLeft  * boost;
+		outBuffer[j+1] += vChan[j+1] * volume * panRight * boost;
 	}
 }
 
@@ -808,8 +823,8 @@ void SampleChannel::stop()
 
 int SampleChannel::load(const char *file, int samplerate, int rsmpQuality)
 {
-	if (strcmp(file, "") == 0 || gIsDir(file)) {
-		gLog("[SampleChannel] file not specified\n");
+	if (strcmp(file, "") == 0 || gu_isDir(file)) {
+		gu_log("[SampleChannel] file not specified\n");
 		return SAMPLE_LEFT_EMPTY;
 	}
 
@@ -819,13 +834,13 @@ int SampleChannel::load(const char *file, int samplerate, int rsmpQuality)
 	Wave *w = new Wave();
 
 	if (!w->open(file)) {
-		gLog("[SampleChannel] %s: read error\n", file);
+		gu_log("[SampleChannel] %s: read error\n", file);
 		delete w;
 		return SAMPLE_READ_ERROR;
 	}
 
 	if (w->channels() > 2) {
-		gLog("[SampleChannel] %s: unsupported multichannel wave\n", file);
+		gu_log("[SampleChannel] %s: unsupported multichannel wave\n", file);
 		delete w;
 		return SAMPLE_MULTICHANNEL;
 	}
@@ -839,7 +854,7 @@ int SampleChannel::load(const char *file, int samplerate, int rsmpQuality)
 		wfx_monoToStereo(w);
 
 	if (w->rate() != samplerate) {
-		gLog("[SampleChannel] input rate (%d) != system rate (%d), conversion needed\n",
+		gu_log("[SampleChannel] input rate (%d) != system rate (%d), conversion needed\n",
 				w->rate(), samplerate);
 		w->resample(rsmpQuality, samplerate);
 	}
@@ -847,7 +862,7 @@ int SampleChannel::load(const char *file, int samplerate, int rsmpQuality)
 	pushWave(w);
 	generateUniqueSampleName();
 
-	gLog("[SampleChannel] %s loaded in channel %d\n", file, index);
+	gu_log("[SampleChannel] %s loaded in channel %d\n", file, index);
 	return SAMPLE_LOADED_OK;
 }
 
@@ -944,8 +959,8 @@ int SampleChannel::readPatch(const string &basePath, int i, Patch *patch,
 
 
 bool SampleChannel::canInputRec()
-	{
-	return wave == NULL;
+{
+	return wave == NULL && armed;
 }
 
 
@@ -953,7 +968,7 @@ bool SampleChannel::canInputRec()
 
 
 void SampleChannel::start(int frame, bool doQuantize, int quantize,
-		bool mixerIsRunning)
+		bool mixerIsRunning, bool forceStart, bool isUserGenerated)
 {
 	switch (status)	{
 		case STATUS_EMPTY:
@@ -962,35 +977,34 @@ void SampleChannel::start(int frame, bool doQuantize, int quantize,
 		{
 			return;
 		}
-
 		case STATUS_OFF:
 		{
 			if (mode & LOOP_ANY) {
-				status = STATUS_WAIT;
+        if (forceStart) {
+          status = STATUS_PLAY;
+          tracker = frame;
+        }
+        else
+				    status = STATUS_WAIT;
 				sendMidiLplay();
 			}
 			else {
 				if (quantize > 0 && mixerIsRunning && doQuantize)
 					qWait = true;
 				else {
-
-					/* fillChan only if frame != 0. If you call fillChan on frame == 0
-					a duplicate call to fillChan occurs with loss of data. Yeah, but
-					what happens if an action really occurs on frame 0 (and it happens,
-					for example	when you start the sequencer from the firt beat)? Cheat
-					time! Shift a little bit the frame, so that it's no longer zero.  */
-
 					status = STATUS_PLAY;
 					sendMidiLplay();
-					if (frame == 0)
-						frame = 2;
-					//if (frame != 0)
+
+					/* Do fillChan only if this is not a user-generated event (i.e. is an
+					action read by Mixer). Otherwise clear() will take take of calling
+					fillChan on the next cycle. */
+
+					if (!isUserGenerated)
 						tracker = fillChan(vChan, tracker, frame);
 				}
 			}
 			break;
 		}
-
 		case STATUS_PLAY:
 		{
 			if (mode == SINGLE_BASIC)
@@ -1009,14 +1023,12 @@ void SampleChannel::start(int frame, bool doQuantize, int quantize,
 			}
 			break;
 		}
-
 		case STATUS_WAIT:
 		{
 			status = STATUS_OFF;
 			sendMidiLplay();
 			break;
 		}
-
 		case STATUS_ENDING:
 		{
 			status = STATUS_PLAY;
@@ -1032,13 +1044,15 @@ void SampleChannel::start(int frame, bool doQuantize, int quantize,
 
 int SampleChannel::writePatch(int i, bool isProject, Patch *patch)
 {
+	// TODO - this code belongs to an upper level (glue)
+
 	int pchIndex = Channel::writePatch(i, isProject, patch);
 	Patch::channel_t *pch = &patch->channels.at(pchIndex);
 
 	if (wave != NULL) {
 		pch->samplePath = wave->pathfile;
 		if (isProject)
-			pch->samplePath = gBasename(wave->pathfile);  // make it portable
+			pch->samplePath = gu_basename(wave->pathfile);  // make it portable
 	}
 	else
 		pch->samplePath = "";
