@@ -89,30 +89,33 @@ public:
 	SampleChannel(int bufferSize, class MidiMapConf *midiMapConf);
 	~SampleChannel();
 
-	void copy(const Channel *src, pthread_mutex_t *pluginMutex);
+	void copy(const Channel *src, pthread_mutex_t *pluginMutex) override;
+	void clear() override;
+	void process(float *outBuffer, float *inBuffer) override;
+	void start(int frame, bool doQuantize, int quantize, bool mixerIsRunning,
+		bool forceStart, bool isUserGenerated) override;
+	void kill(int frame) override;
+	void empty() override;
+	void stopBySeq(bool chansStopOnSeqHalt) override;
+	void stop() override;
+	void rewind() override;
+	void setMute(bool internal) override;
+	void unsetMute(bool internal) override;
+	int readPatch_DEPR_(const char *file, int i, class Patch_DEPR_ *patch,
+			int samplerate, int rsmpQuality) override;
+  int readPatch(const string &basePath, int i, class Patch *patch,
+			pthread_mutex_t *pluginMutex, int samplerate, int rsmpQuality) override;
+	int writePatch(int i, bool isProject, class Patch *patch) override;
+	void quantize(int index, int localFrame, class Mixer *m) override;
+	void onZero(int frame, bool recsStopOnChanHalt) override;
+	void onBar(int frame) override;
+	void parseAction(Recorder::action *a, int localFrame, int globalFrame,
+			int quantize, bool mixerIsRunning) override;
+	bool canInputRec() override;
 
-	void clear      ();
-	void process    (float *buffer);
-	void start      (int frame, bool doQuantize, int quantize, bool mixerIsRunning);
-	void kill       (int frame);
-	void empty      ();
-	void stopBySeq  (bool chansStopOnSeqHalt);
-	void stop       ();
-	void rewind     ();
-	void setMute    (bool internal);
-	void unsetMute  (bool internal);
-	void reset      (int frame);
-	int  load       (const char *file, int samplerate, int rsmpQuality);
-	int  readPatch_DEPR_  (const char *file, int i, class Patch_DEPR_ *patch,
-			int samplerate, int rsmpQuality);
-  int  readPatch  (const string &basePath, int i, class Patch *patch,
-			pthread_mutex_t *pluginMutex, int samplerate, int rsmpQuality);
-	int  writePatch (int i, bool isProject, class Patch *patch);
-	void quantize   (int index, int localFrame, int globalFrame);
-	void onZero     (int frame, bool recsStopOnChanHalt);
-	void onBar      (int frame);
-	void parseAction(recorder::action *a, int localFrame, int globalFrame,
-			int quantize, bool mixerIsRunning);
+	int load(const char *file, int samplerate, int rsmpQuality);
+
+	void reset(int frame);
 
 	/* fade methods
 	 * prepare channel for fade, mixer will take care of the process
@@ -165,13 +168,8 @@ public:
 
 	bool allocEmpty(int frames, int samplerate, int takeId);
 
-	/* canInputRec
-	 * true if channel can host a new wave from input recording. */
-
-	bool  canInputRec();
-
 	/* setReadActions
-	 * if enabled, recorder will read actions from this channel. If
+	 * if enabled (v == true), recorder will read actions from this channel. If
 	 * recsStopOnChanHalt == true, stop reading actions right away. */
 
 	void setReadActions(bool v, bool recsStopOnChanHalt);
@@ -195,10 +193,6 @@ public:
   int    fadeoutType;     // xfade or fadeout
   int		 fadeoutEnd;      // what to do when fadeout ends
 
-	/* recorder:: stuff */
-
-  bool   readActions;     // read actions or not
-
 	/* midi stuff */
 
   uint32_t midiInReadActions;
