@@ -28,18 +28,19 @@
 
 
 #include <math.h>
-#include "../../utils/gui_utils.h"
+#include "../../utils/gui.h"
 #include "../../core/graphics.h"
 #include "../../core/mixer.h"
 #include "../../core/recorder.h"
 #include "../../core/conf.h"
 #include "../../core/channel.h"
 #include "../../core/sampleChannel.h"
-#include "../elems/ge_actionChannel.h"
-#include "../elems/ge_muteChannel.h"
-#include "../elems/ge_envelopeChannel.h"
-#include "../elems/ge_pianoRoll.h"
+#include "../elems/actionEditor.h"
+#include "../elems/envelopeEditor.h"
+#include "../elems/muteEditor.h"
+#include "../elems/noteEditor.h"
 #include "../elems/ge_mixed.h"
+#include "../elems/basics/scroll.h"
 #include "gd_actionEditor.h"
 
 
@@ -94,15 +95,15 @@ gdActionEditor::gdActionEditor(Channel *chan)
 
 	/* main scroller: contains all widgets */
 
-	scroller = new gScroll(8, 36, w()-16, h()-44);
+	scroller = new geScroll(8, 36, w()-16, h()-44);
 
 	if (chan->type == CHANNEL_SAMPLE) {
 
 		SampleChannel *ch = (SampleChannel*) chan;
 
-		ac = new gActionChannel     (scroller->x(), upperArea->y()+upperArea->h()+8, this, ch);
-		mc = new gMuteChannel       (scroller->x(), ac->y()+ac->h()+8, this);
-		vc = new gEnvelopeChannel   (scroller->x(), mc->y()+mc->h()+8, this, ACTION_VOLUME, RANGE_FLOAT, "volume");
+		ac = new geActionEditor  (scroller->x(), upperArea->y()+upperArea->h()+8, this, ch);
+		mc = new geMuteEditor    (scroller->x(), ac->y()+ac->h()+8, this);
+		vc = new geEnvelopeEditor(scroller->x(), mc->y()+mc->h()+8, this, ACTION_VOLUME, RANGE_FLOAT, "volume");
 		scroller->add(ac);
 		//scroller->add(new gResizerBar(ac->x(), ac->y()+ac->h(), scroller->w(), 8));
 		scroller->add(mc);
@@ -121,7 +122,7 @@ gdActionEditor::gdActionEditor(Channel *chan)
 			ac->deactivate();
 	}
 	else {
-		pr = new gPianoRollContainer(scroller->x(), upperArea->y()+upperArea->h()+8, this);
+		pr = new geNoteEditor(scroller->x(), upperArea->y()+upperArea->h()+8, this);
 		scroller->add(pr);
 		scroller->add(new gResizerBar(pr->x(), pr->y()+pr->h(), scroller->w(), 8));
 	}
