@@ -28,16 +28,11 @@
 
 
 #include "../../core/graphics.h"
-#include "../../core/wave.h"
-#include "../../core/channel.h"
-#include "../../core/sampleChannel.h"
 #include "../../core/conf.h"
-#include "../../glue/glue.h"
-#include "../../glue/channel.h"
-#include "../../glue/storage.h"
-#include "../../utils/gui_utils.h"
-#include "../elems/ge_browser.h"
-#include "../elems/ge_channel.h"
+#include "../../core/const.h"
+#include "../../utils/gui.h"
+#include "../elems/ge_mixed.h"
+#include "../elems/browser.h"
 #include "gd_browser.h"
 
 
@@ -53,19 +48,22 @@ gdBaseBrowser::gdBaseBrowser(int x, int y, int w, int h, const string &title,
 {
 	set_non_modal();
 
-	groupTop = new Fl_Group(8, 8, w-16, 20);
-		where = new gInput(groupTop->x(), groupTop->y(), 152, 20);
-		updir	= new gClick(groupTop->x()+groupTop->w()-20, groupTop->y(), 20, 20, "", updirOff_xpm, updirOn_xpm);
+	groupTop = new Fl_Group(8, 8, w-16, 40);
+    hiddenFiles = new gCheck(groupTop->x(), groupTop->y(), 400, 20, "Show hidden files");
+		where = new gInput(groupTop->x(), hiddenFiles->y()+hiddenFiles->h(), 152, 20);
+		updir	= new gClick(groupTop->x()+groupTop->w()-20, where->y(), 20, 20, "", updirOff_xpm, updirOn_xpm);
 	groupTop->end();
 	groupTop->resizable(where);
 
+  hiddenFiles->callback(cb_toggleHiddenFiles, (void*) this);
+
 	where->readonly(true);
 	where->cursor_color(COLOR_BG_DARK);
 	where->value(path.c_str());
 
 	updir->callback(cb_up, (void*) this);
 
-	browser = new gBrowser(8, groupTop->y()+groupTop->h()+8, w-16, h-73);
+	browser = new geBrowser(8, groupTop->y()+groupTop->h()+8, w-16, h-93);
 	browser->loadDir(path);
 	if (path == G_Conf.browserLastPath)
 		browser->preselect(G_Conf.browserPosition, G_Conf.browserLastValue);
@@ -102,7 +100,7 @@ gdBaseBrowser::~gdBaseBrowser()
 	G_Conf.browserW = w();
 	G_Conf.browserH = h();
 	G_Conf.browserPosition = browser->position();
-	G_Conf.browserLastPath = gDirname(browser->getSelectedItem());
+	G_Conf.browserLastPath = gu_dirname(browser->getSelectedItem());
 	G_Conf.browserLastValue = browser->value();
 }
 
@@ -112,12 +110,14 @@ gdBaseBrowser::~gdBaseBrowser()
 
 void gdBaseBrowser::cb_up   (Fl_Widget *v, void *p) { ((gdBaseBrowser*)p)->__cb_up(); }
 void gdBaseBrowser::cb_close(Fl_Widget *v, void *p) { ((gdBaseBrowser*)p)->__cb_close(); }
+void gdBaseBrowser::cb_toggleHiddenFiles(Fl_Widget *v, void *p) { ((gdBaseBrowser*)p)->__cb_toggleHiddenFiles(); }
 
 
 /* -------------------------------------------------------------------------- */
 
 
-void gdBaseBrowser::__cb_up() {
+void gdBaseBrowser::__cb_up()
+{
 	string dir = browser->getCurrentDir();
 	dir = dir.substr(0, dir.find_last_of(G_SLASH_STR));  // remove up to the next slash
 	browser->loadDir(dir);
@@ -128,7 +128,8 @@ void gdBaseBrowser::__cb_up() {
 /* -------------------------------------------------------------------------- */
 
 
-void gdBaseBrowser::__cb_close() {
+void gdBaseBrowser::__cb_close()
+{
 	do_callback();
 }
 
@@ -136,6 +137,15 @@ void gdBaseBrowser::__cb_close() {
 /* -------------------------------------------------------------------------- */
 
 
+void gdBaseBrowser::__cb_toggleHiddenFiles()
+{
+	browser->toggleHiddenFiles();
+}
+
+
+/* -------------------------------------------------------------------------- */
+
+
 void gdBaseBrowser::setStatusBar(float v)
 {
 	status->value(status->value() + v);
@@ -146,6 +156,33 @@ void gdBaseBrowser::setStatusBar(float v)
 /* -------------------------------------------------------------------------- */
 
 
+void gdBaseBrowser::showStatusBar()
+{
+  status->show();
+}
+
+
+/* -------------------------------------------------------------------------- */
+
+
+void gdBaseBrowser::hideStatusBar()
+{
+  status->hide();
+}
+
+
+/* -------------------------------------------------------------------------- */
+
+
+string gdBaseBrowser::getCurrentPath()
+{
+  return where->value();
+}
+
+
+/* -------------------------------------------------------------------------- */
+
+
 string gdBaseBrowser::getSelectedItem()
 {
 	return browser->getSelectedItem();
@@ -165,7 +202,7 @@ gdSaveBrowser::gdSaveBrowser(int x, int y, int w, int h, const string &title,
 
 	where->size(groupTop->w()-236, 20);
 
-	name = new gInput(where->x()+where->w()+8, 8, 200, 20);
+	name = new gInput(where->x()+where->w()+8, where->y(), 200, 20);
 	name->value(_name.c_str());
 	groupTop->add(name);
 
@@ -197,7 +234,7 @@ void gdSaveBrowser::__cb_down()
 	/* if the selected item is a directory just load its content. If it's a file
 	 * use it as the file name (i.e. fill name->value()). */
 
-	if (gIsDir(path)) {
+	if (gu_isDir(path)) {
 		browser->loadDir(path);
 		where->value(browser->getCurrentDir().c_str());
 	}
@@ -209,6 +246,15 @@ void gdSaveBrowser::__cb_down()
 /* -------------------------------------------------------------------------- */
 
 
+string gdSaveBrowser::getName()
+{
+  return name->value();
+}
+
+
+/* -------------------------------------------------------------------------- */
+
+
 void gdSaveBrowser::__cb_save()
 {
 	callback((void*) this);
@@ -261,7 +307,7 @@ void gdLoadBrowser::__cb_down()
 {
 	string path = browser->getSelectedItem();
 
-	if (path.empty() || !gIsDir(path)) // when click on an empty area or not a dir
+	if (path.empty() || !gu_isDir(path)) // when click on an empty area or not a dir
 		return;
 
 	browser->loadDir(path);
