@@ -27,15 +27,19 @@
  * -------------------------------------------------------------------------- */
 
 
+#include <RtMidi.h>
+#include <FL/Fl_Tabs.H>
 #include "../../core/conf.h"
 #include "../../core/midiMapConf.h"
 #include "../../core/patch_DEPR_.h"
 #include "../../core/kernelAudio.h"
 #include "../../core/kernelMidi.h"
 #include "../../core/pluginHost.h"
-#include "../../utils/gui_utils.h"
+#include "../../utils/gui.h"
 #include "../../utils/log.h"
+#include "../../utils/string.h"
 #include "../elems/ge_mixed.h"
+#include "../elems/basics/boxtypes.h"
 #include "gd_config.h"
 #include "gd_keyGrabber.h"
 #include "gd_devInfo.h"
@@ -44,6 +48,8 @@
 
 extern Patch_DEPR_ G_Patch_DEPR_;
 extern Conf	       G_Conf;
+extern KernelAudio G_KernelAudio;
+extern KernelMidi  G_KernelMidi;
 extern bool        G_audio_status;
 extern MidiMapConf G_MidiMap;
 
@@ -131,11 +137,11 @@ gTabAudio::gTabAudio(int X, int Y, int W, int H)
 
 #if defined(__linux__)
 
-	if (kernelAudio::hasAPI(RtAudio::LINUX_ALSA))
+	if (G_KernelAudio.hasAPI(RtAudio::LINUX_ALSA))
 		soundsys->add("ALSA");
-	if (kernelAudio::hasAPI(RtAudio::UNIX_JACK))
+	if (G_KernelAudio.hasAPI(RtAudio::UNIX_JACK))
 		soundsys->add("Jack");
-	if (kernelAudio::hasAPI(RtAudio::LINUX_PULSE))
+	if (G_KernelAudio.hasAPI(RtAudio::LINUX_PULSE))
 		soundsys->add("PulseAudio");
 
 	switch (G_Conf.soundSystem) {
@@ -157,11 +163,11 @@ gTabAudio::gTabAudio(int X, int Y, int W, int H)
 
 #elif defined(_WIN32)
 
-	if (kernelAudio::hasAPI(RtAudio::WINDOWS_DS))
+	if (G_KernelAudio.hasAPI(RtAudio::WINDOWS_DS))
 		soundsys->add("DirectSound");
-	if (kernelAudio::hasAPI(RtAudio::WINDOWS_ASIO))
+	if (G_KernelAudio.hasAPI(RtAudio::WINDOWS_ASIO))
 		soundsys->add("ASIO");
-	if (kernelAudio::hasAPI(RtAudio::WINDOWS_WASAPI))
+	if (G_KernelAudio.hasAPI(RtAudio::WINDOWS_WASAPI))
 		soundsys->add("WASAPI");
 
 	switch (G_Conf.soundSystem) {
@@ -181,7 +187,7 @@ gTabAudio::gTabAudio(int X, int Y, int W, int H)
 
 #elif defined (__APPLE__)
 
-	if (kernelAudio::hasAPI(RtAudio::MACOSX_CORE))
+	if (G_KernelAudio.hasAPI(RtAudio::MACOSX_CORE))
 		soundsys->add("CoreAudio");
 
 	switch (G_Conf.soundSystem) {
@@ -213,10 +219,10 @@ gTabAudio::gTabAudio(int X, int Y, int W, int H)
 		/* fill frequency dropdown menu */
 		/* TODO - add fetchFrequencies() */
 
-		int nfreq = kernelAudio::getTotalFreqs(sounddevOut->value());
+		int nfreq = G_KernelAudio.getTotalFreqs(sounddevOut->value());
 		for (int i=0; i<nfreq; i++) {
-			int freq = kernelAudio::getFreq(sounddevOut->value(), i);
-			samplerate->add(gItoa(freq).c_str());
+			int freq = G_KernelAudio.getFreq(sounddevOut->value(), i);
+			samplerate->add(gu_itoa(freq).c_str());
 			if (freq == G_Conf.samplerate)
 				samplerate->value(i);
 		}
@@ -241,7 +247,7 @@ gTabAudio::gTabAudio(int X, int Y, int W, int H)
 	buffersize->add("1024");
 	buffersize->add("2048");
 	buffersize->add("4096");
-	buffersize->showItem(gItoa(G_Conf.buffersize).c_str());
+	buffersize->showItem(gu_itoa(G_Conf.buffersize).c_str());
 
 	rsmpQuality->add("Sinc best quality (very slow)");
 	rsmpQuality->add("Sinc medium quality (slow)");
@@ -250,7 +256,7 @@ gTabAudio::gTabAudio(int X, int Y, int W, int H)
 	rsmpQuality->add("Linear (very fast)");
 	rsmpQuality->value(G_Conf.rsmpQuality);
 
-	delayComp->value(gItoa(G_Conf.delayComp).c_str());
+	delayComp->value(gu_itoa(G_Conf.delayComp).c_str());
 	delayComp->type(FL_INT_INPUT);
 	delayComp->maximum_size(5);
 
@@ -293,7 +299,7 @@ void gTabAudio::__cb_fetchOutChans()
 
 void gTabAudio::__cb_showInputInfo()
 {
-	unsigned dev = kernelAudio::getDeviceByName(sounddevIn->text(sounddevIn->value()));
+	unsigned dev = G_KernelAudio.getDeviceByName(sounddevIn->text(sounddevIn->value()));
 	new gdDevInfo(dev);
 }
 
@@ -303,7 +309,7 @@ void gTabAudio::__cb_showInputInfo()
 
 void gTabAudio::__cb_showOutputInfo()
 {
-	unsigned dev = kernelAudio::getDeviceByName(sounddevOut->text(sounddevOut->value()));
+	unsigned dev = G_KernelAudio.getDeviceByName(sounddevOut->text(sounddevOut->value()));
 	new gdDevInfo(dev);
 }
 
@@ -374,8 +380,8 @@ void gTabAudio::fetchInChans(int menuItem)
 
 	channelsIn->clear();
 
-	unsigned dev = kernelAudio::getDeviceByName(sounddevIn->text(sounddevIn->value()));
-	unsigned chs = kernelAudio::getMaxInChans(dev);
+	unsigned dev = G_KernelAudio.getDeviceByName(sounddevIn->text(sounddevIn->value()));
+	unsigned chs = G_KernelAudio.getMaxInChans(dev);
 
 	if (chs == 0) {
 		channelsIn->add("none");
@@ -398,8 +404,8 @@ void gTabAudio::fetchOutChans(int menuItem)
 {
 	channelsOut->clear();
 
-	unsigned dev = kernelAudio::getDeviceByName(sounddevOut->text(sounddevOut->value()));
-	unsigned chs = kernelAudio::getMaxOutChans(dev);
+	unsigned dev = G_KernelAudio.getDeviceByName(sounddevOut->text(sounddevOut->value()));
+	unsigned chs = G_KernelAudio.getMaxOutChans(dev);
 
 	if (chs == 0) {
 		channelsOut->add("none");
@@ -427,11 +433,11 @@ int gTabAudio::findMenuDevice(gChoice *m, int device)
 		return 0;
 
 	for (int i=0; i<m->size(); i++) {
-		if (kernelAudio::getDeviceName(device) == "")
+		if (G_KernelAudio.getDeviceName(device) == "")
 			continue;
 		if (m->text(i) == NULL)
 			continue;
-		if (m->text(i) == kernelAudio::getDeviceName(device))
+		if (m->text(i) == G_KernelAudio.getDeviceName(device))
 			return i;
 	}
 
@@ -444,7 +450,7 @@ int gTabAudio::findMenuDevice(gChoice *m, int device)
 
 void gTabAudio::fetchSoundDevs()
 {
-	if (kernelAudio::numDevs == 0) {
+	if (G_KernelAudio.numDevs == 0) {
 		sounddevOut->add("-- no devices found --");
 		sounddevOut->value(0);
 		sounddevIn->add("-- no devices found --");
@@ -462,11 +468,11 @@ void gTabAudio::fetchSoundDevs()
 
 		sounddevIn->add("(disabled)");
 
-		for (unsigned i=0; i<kernelAudio::numDevs; i++) {
+		for (unsigned i=0; i<G_KernelAudio.numDevs; i++) {
 
 			/* escaping '/', very dangerous in FLTK (it creates a submenu) */
 
-			string tmp = kernelAudio::getDeviceName(i);
+			string tmp = G_KernelAudio.getDeviceName(i);
 			for (unsigned k=0; k<tmp.size(); k++)
 				if (tmp[k] == '/' || tmp[k] == '|' || tmp[k] == '&' || tmp[k] == '_')
 					tmp[k] = '-';
@@ -475,10 +481,10 @@ void gTabAudio::fetchSoundDevs()
 			 * way we can filter devices only for input or output, e.g. an input
 			 * devices has 0 output channels. */
 
-			if (kernelAudio::getMaxOutChans(i) > 0)
+			if (G_KernelAudio.getMaxOutChans(i) > 0)
 				sounddevOut->add(tmp.c_str());
 
-			if (kernelAudio::getMaxInChans(i) > 0)
+			if (G_KernelAudio.getMaxInChans(i) > 0)
 				sounddevIn->add(tmp.c_str());
 		}
 
@@ -534,6 +540,8 @@ void gTabAudio::save()
 		G_Conf.soundSystem = SYS_API_DS;
 	else if (text == "ASIO")
 		G_Conf.soundSystem = SYS_API_ASIO;
+	else if (text == "WASAPI")
+		G_Conf.soundSystem = SYS_API_WASAPI;
 
 #elif defined (__APPLE__)
 
@@ -544,8 +552,8 @@ void gTabAudio::save()
 
 	/* use the device name to search into the drop down menu's */
 
-	G_Conf.soundDeviceOut = kernelAudio::getDeviceByName(sounddevOut->text(sounddevOut->value()));
-	G_Conf.soundDeviceIn  = kernelAudio::getDeviceByName(sounddevIn->text(sounddevIn->value()));
+	G_Conf.soundDeviceOut = G_KernelAudio.getDeviceByName(sounddevOut->text(sounddevOut->value()));
+	G_Conf.soundDeviceIn  = G_KernelAudio.getDeviceByName(sounddevIn->text(sounddevIn->value()));
 	G_Conf.channelsOut    = channelsOut->value();
 	G_Conf.channelsIn     = channelsIn->value();
 	G_Conf.limitOutput    = limitOutput->value();
@@ -620,7 +628,7 @@ gTabMidi::gTabMidi(int X, int Y, int W, int H)
 
 void gTabMidi::fetchOutPorts() {
 
-	if (kernelMidi::numOutPorts == 0) {
+	if (G_KernelMidi.numOutPorts == 0) {
 		portOut->add("-- no ports found --");
 		portOut->value(0);
 		portOut->deactivate();
@@ -629,8 +637,8 @@ void gTabMidi::fetchOutPorts() {
 
 		portOut->add("(disabled)");
 
-		for (unsigned i=0; i<kernelMidi::numOutPorts; i++)
-			portOut->add(gu_removeFltkChars(kernelMidi::getOutPortName(i)).c_str());
+		for (unsigned i=0; i<G_KernelMidi.numOutPorts; i++)
+			portOut->add(gu_removeFltkChars(G_KernelMidi.getOutPortName(i)).c_str());
 
 		portOut->value(G_Conf.midiPortOut+1);    // +1 because midiPortOut=-1 is '(disabled)'
 	}
@@ -641,7 +649,7 @@ void gTabMidi::fetchOutPorts() {
 
 void gTabMidi::fetchInPorts()
 {
-	if (kernelMidi::numInPorts == 0) {
+	if (G_KernelMidi.numInPorts == 0) {
 		portIn->add("-- no ports found --");
 		portIn->value(0);
 		portIn->deactivate();
@@ -650,8 +658,8 @@ void gTabMidi::fetchInPorts()
 
 		portIn->add("(disabled)");
 
-		for (unsigned i=0; i<kernelMidi::numInPorts; i++)
-			portIn->add(gu_removeFltkChars(kernelMidi::getInPortName(i)).c_str());
+		for (unsigned i=0; i<G_KernelMidi.numInPorts; i++)
+			portIn->add(gu_removeFltkChars(G_KernelMidi.getInPortName(i)).c_str());
 
 		portIn->value(G_Conf.midiPortIn+1);    // +1 because midiPortIn=-1 is '(disabled)'
 	}
@@ -678,7 +686,7 @@ void gTabMidi::fetchMidiMaps()
 	}
 
 	/* Preselect the 0 midimap if nothing is selected but midimaps exist. */
-	
+
 	if (midiMap->value() == -1 && G_MidiMap.maps.size() > 0)
 		midiMap->value(0);
 }
@@ -722,14 +730,14 @@ void gTabMidi::fetchSystems()
 {
 #if defined(__linux__)
 
-	if (kernelMidi::hasAPI(RtMidi::LINUX_ALSA))
+	if (G_KernelMidi.hasAPI(RtMidi::LINUX_ALSA))
 		system->add("ALSA");
-	if (kernelMidi::hasAPI(RtMidi::UNIX_JACK))
+	if (G_KernelMidi.hasAPI(RtMidi::UNIX_JACK))
 		system->add("Jack");
 
 #elif defined(_WIN32)
 
-	if (kernelMidi::hasAPI(RtMidi::WINDOWS_MM))
+	if (G_KernelMidi.hasAPI(RtMidi::WINDOWS_MM))
 		system->add("Multimedia MIDI");
 
 #elif defined (__APPLE__)
@@ -887,7 +895,7 @@ gTabPlugins::gTabPlugins(int X, int Y, int W, int H)
 
 void gTabPlugins::updateCount()
 {
-	string scanLabel = "Scan (" + gItoa(G_PluginHost.countAvailablePlugins()) + " found)";
+	string scanLabel = "Scan (" + gu_itoa(G_PluginHost.countAvailablePlugins()) + " found)";
 	scanButton->label(scanLabel.c_str());
 }
 
@@ -903,7 +911,7 @@ void gTabPlugins::cb_scan(Fl_Widget *w, void *p) { ((gTabPlugins*)p)->__cb_scan(
 
 void gTabPlugins::cb_onScan(float progress, void *p)
 {
-	string l = "Scan in progress (" + gItoa((int)(progress*100)) + "%). Please wait...";
+	string l = "Scan in progress (" + gu_itoa((int)(progress*100)) + "%). Please wait...";
 	((gTabPlugins *)p)->info->label(l.c_str());
 	Fl::wait();
 }
@@ -916,7 +924,7 @@ void gTabPlugins::__cb_scan(Fl_Widget *w)
 {
 	info->show();
 	G_PluginHost.scanDir(folderPath->value(), cb_onScan, (void*) this);
-	G_PluginHost.saveList(gGetHomePath() + G_SLASH + "plugins.xml");
+	G_PluginHost.saveList(gu_getHomePath() + G_SLASH + "plugins.xml");
 	info->hide();
 	updateCount();
 }
@@ -947,6 +955,10 @@ gdConfig::gdConfig(int w, int h) : gWindow(w, h, "Configuration")
 		resize(G_Conf.configX, G_Conf.configY, this->w(), this->h());
 
 	Fl_Tabs *tabs = new Fl_Tabs(8, 8, w-16, h-44);
+  tabs->box(G_CUSTOM_BORDER_BOX);
+  tabs->labelcolor(COLOR_TEXT_0);
+  tabs->begin();
+
 		tabAudio     = new gTabAudio(tabs->x()+10, tabs->y()+20, tabs->w()-20, tabs->h()-40);
 		tabMidi      = new gTabMidi(tabs->x()+10, tabs->y()+20, tabs->w()-20, tabs->h()-40);
 		tabBehaviors = new gTabBehaviors(tabs->x()+10, tabs->y()+20, tabs->w()-20, tabs->h()-40);
@@ -962,10 +974,6 @@ gdConfig::gdConfig(int w, int h) : gWindow(w, h, "Configuration")
 
 	end();
 
-	tabs->box(FL_FLAT_BOX); // TODO - G_BOX crashes FLTK 1.3.3
-
-	tabs->labelcolor(COLOR_TEXT_0);
-
 	save->callback(cb_save_config, (void*)this);
 	cancel->callback(cb_cancel, (void*)this);
 
