@@ -31,9 +31,10 @@
 
 
 #include <FL/Fl_Scroll.H>
-#include "../../utils/gui_utils.h"
+#include "../../utils/gui.h"
 #include "../../core/plugin.h"
 #include "../elems/ge_mixed.h"
+#include "../elems/basics/boxtypes.h"
 #include "gd_pluginWindow.h"
 
 
@@ -46,7 +47,7 @@ Parameter::Parameter(int paramIndex, Plugin *p, int X, int Y, int W)
 	begin();
 
 		label = new gBox(x(), y(), 60, 20);
-		label->copy_label(pPlugin->getParameterName(paramIndex).toRawUTF8());
+		label->copy_label(pPlugin->getParameterName(paramIndex).c_str());
 		label->align(FL_ALIGN_LEFT | FL_ALIGN_INSIDE);
 
 		slider = new gSlider(label->x()+label->w()+8, y(), W-200, 20);
@@ -55,7 +56,7 @@ Parameter::Parameter(int paramIndex, Plugin *p, int X, int Y, int W)
 
 		value = new gBox(slider->x()+slider->w()+8, y(), 100, 20);
 		value->align(FL_ALIGN_LEFT | FL_ALIGN_INSIDE);
-		value->box(G_BOX);
+		value->box(G_CUSTOM_BORDER_BOX);
 		updateValue();
 
 		resizable(slider);
@@ -86,8 +87,8 @@ void Parameter::__cb_setValue()
 
 void Parameter::updateValue()
 {
-	string v = pPlugin->getParameterText(paramIndex).toStdString() + " " +
-			pPlugin->getParameterLabel(paramIndex).toStdString();
+	string v = pPlugin->getParameterText(paramIndex) + " " +
+			pPlugin->getParameterLabel(paramIndex);
 	value->copy_label(v.c_str());
 }
 
@@ -113,7 +114,7 @@ gdPluginWindow::gdPluginWindow(Plugin *p)
 
 	end();
 
-	label(pPlugin->getName().toRawUTF8());
+	label(pPlugin->getName().c_str());
 
 	size_range(400, (24*1)+12);
 	resizable(list);
