@@ -34,8 +34,9 @@
 #include "../../core/recorder.h"
 #include "../../core/channel.h"
 #include "../../core/sampleChannel.h"
-#include "../../utils/gui_utils.h"
+#include "../../utils/gui.h"
 #include "../dialogs/gd_mainWindow.h"
+#include "basics/boxtypes.h"
 #include "ge_mixed.h"
 
 
@@ -130,8 +131,8 @@ void gClickRepeat::draw()
 gInput::gInput(int x, int y, int w, int h, const char *L)
 : Fl_Input(x, y, w, h, L)
 {
-  //Fl::set_boxtype(G_BOX, gDrawBox, 1, 1, 2, 2);
-  box(G_BOX);
+  //Fl::set_boxtype(G_CUSTOM_BORDER_BOX, gDrawBox, 1, 1, 2, 2);
+  box(G_CUSTOM_BORDER_BOX);
   labelsize(GUI_FONT_SIZE_BASE);
   labelcolor(COLOR_TEXT_0);
   color(COLOR_BG_DARK);
@@ -173,8 +174,9 @@ void gDial::draw()
 
 
 gBox::gBox(int x, int y, int w, int h, const char *L, Fl_Align al)
-: Fl_Box(x, y, w, h, L)
+: Fl_Box(x, y, w, h)
 {
+  copy_label(L);
   labelsize(GUI_FONT_SIZE_BASE);
   box(FL_NO_BOX);
   labelcolor(COLOR_TEXT_0);
@@ -241,7 +243,7 @@ void gRadio::draw()
 gProgress::gProgress(int x, int y, int w, int h, const char *L)
 : Fl_Progress(x, y, w, h, L) {
   color(COLOR_BG_0, COLOR_BD_0);
-  box(G_BOX);
+  box(G_CUSTOM_BORDER_BOX);
 
 }
 
@@ -294,38 +296,6 @@ void gSoundMeter::draw()
   fl_rectf(x()+1, y()+1, (int) px_level, h()-2, clip || !G_audio_status ? COLOR_ALERT : COLOR_BD_0);
 }
 
-/* -------------------------------------------------------------------------- */
-
-gBeatMeter::gBeatMeter(int x, int y, int w, int h, const char *L)
-  : Fl_Box(x, y, w, h, L) {}
-
-void gBeatMeter::draw()
-{
-  int cursorW = w() / MAX_BEATS;
-  int greyX   = G_Mixer.beats * cursorW;
-
-  fl_rect(x(), y(), w(), h(), COLOR_BD_0);                                // border
-  fl_rectf(x()+1, y()+1, w()-2, h()-2, FL_BACKGROUND_COLOR);              // bg
-  fl_rectf(x()+(G_Mixer.actualBeat*cursorW)+3, y()+3, cursorW-5, h()-6, COLOR_BG_2); // cursor
-
-  /* beat cells */
-
-  fl_color(COLOR_BD_0);
-  for (int i=1; i<=G_Mixer.beats; i++)
-    fl_line(x()+cursorW*i, y()+1, x()+cursorW*i, y()+h()-2);
-
-  /* bar line */
-
-  fl_color(COLOR_BG_2);
-  int delta = G_Mixer.beats / G_Mixer.bars;
-  for (int i=1; i<G_Mixer.bars; i++)
-    fl_line(x()+cursorW*(i*delta), y()+1, x()+cursorW*(i*delta), y()+h()-2);
-
-  /* unused grey area */
-
-  fl_rectf(x()+greyX+1, y()+1, w()-greyX-1,  h()-2, COLOR_BG_1);
-}
-
 
 /* -------------------------------------------------------------------------- */
 
@@ -375,18 +345,6 @@ void gChoice::draw()
 /* -------------------------------------------------------------------------- */
 
 
-void gDrawBox(int x, int y, int w, int h, Fl_Color c)
-{
-  fl_color(c);
-  fl_rectf(x, y, w, h);
-  fl_color(COLOR_BD_0);
-  fl_rect(x, y, w, h);
-}
-
-
-/* -------------------------------------------------------------------------- */
-
-
 gLiquidScroll::gLiquidScroll(int x, int y, int w, int h, const char *l)
   : Fl_Scroll(x, y, w, h, l)
 {
@@ -394,7 +352,7 @@ gLiquidScroll::gLiquidScroll(int x, int y, int w, int h, const char *l)
   scrollbar.color(COLOR_BG_0);
   scrollbar.selection_color(COLOR_BG_1);
   scrollbar.labelcolor(COLOR_BD_1);
-  scrollbar.slider(G_BOX);
+  scrollbar.slider(G_CUSTOM_BORDER_BOX);
 }
 
 
@@ -422,7 +380,7 @@ gSlider::gSlider(int x, int y, int w, int h, const char *l)
   align(FL_ALIGN_LEFT);
   labelcolor(COLOR_TEXT_0);
 
-  box(G_BOX);
+  box(G_CUSTOM_BORDER_BOX);
   color(COLOR_BG_0);
   selection_color(COLOR_BD_0);
 }
@@ -452,7 +410,7 @@ gResizerBar::gResizerBar(int X,int Y,int W,int H, bool vertical)
 /*
 gResizerBar::~gResizerBar()
 {
-  gLog("------ resizerbar %p destroyed\n", (void*)this);
+  gu_log("------ resizerbar %p destroyed\n", (void*)this);
 }
 */
 
@@ -563,26 +521,6 @@ void gResizerBar::resize(int X,int Y,int W,int H)
 }
 
 
-/* -------------------------------------------------------------------------- */
-
-
-gScroll::gScroll(int x, int y, int w, int h, int t)
-  : Fl_Scroll(x, y, w, h)
-{
-  type(t);
-
-  scrollbar.color(COLOR_BG_0);
-  scrollbar.selection_color(COLOR_BG_1);
-  scrollbar.labelcolor(COLOR_BD_1);
-  scrollbar.slider(G_BOX);
-
-  hscrollbar.color(COLOR_BG_0);
-  hscrollbar.selection_color(COLOR_BG_1);
-  hscrollbar.labelcolor(COLOR_BD_1);
-  hscrollbar.slider(G_BOX);
-}
-
-
 /* -------------------------------------------------------------------------- */
 /* -------------------------------------------------------------------------- */
 /* -------------------------------------------------------------------------- */
