@@ -33,14 +33,16 @@
 #include <samplerate.h>
 #include "../../core/wave.h"
 #include "../../core/conf.h"
+#include "../../core/const.h"
 #include "../../core/mixer.h"
 #include "../../core/waveFx.h"
 #include "../../core/channel.h"
 #include "../../core/sampleChannel.h"
-#include "../../glue/glue.h"
+#include "../../glue/channel.h"
 #include "../dialogs/gd_editor.h"
 #include "ge_waveTools.h"
 #include "ge_mixed.h"
+#include "basics/boxtypes.h"
 #include "ge_waveform.h"
 
 
@@ -250,7 +252,7 @@ void gWaveform::draw()
 
     for (unsigned k=0; k<grid.points.size(); k++) {
       if (grid.points.at(k) == i) {
-        //gLog("draw grid line at %d\n", i);
+        //gu_log("draw grid line at %d\n", i);
         fl_color(fl_rgb_color(54, 54, 54));
         fl_line_style(FL_DASH, 0, NULL);
         fl_line(i+x(), y(), i+x(), y()+h());
@@ -620,7 +622,7 @@ void gWaveform::openEditMenu()
   }
 
   Fl_Menu_Button *b = new Fl_Menu_Button(0, 0, 100, 50);
-  b->box(G_BOX);
+  b->box(G_CUSTOM_BORDER_BOX);
   b->textsize(GUI_FONT_SIZE_BASE);
   b->textcolor(COLOR_TEXT_0);
   b->color(COLOR_BG_0);
