@@ -38,16 +38,20 @@
 #include "core/mixer.h"
 #include "core/mixerHandler.h"
 #include "core/kernelAudio.h"
+#include "core/kernelMidi.h"
 #include "core/recorder.h"
-#include "utils/gui_utils.h"
+#include "utils/gui.h"
 #include "gui/dialogs/gd_mainWindow.h"
 #include "core/pluginHost.h"
 
 
 /* global variables. Yeah, we are nasty */
 
-pthread_t     t_video;
+pthread_t     G_videoThread;
+KernelAudio   G_KernelAudio;
 Mixer         G_Mixer;
+Recorder      G_Recorder;
+KernelMidi    G_KernelMidi;
 bool          G_quit;
 bool	        G_audio_status;
 bool          G_midiStatus;
@@ -55,18 +59,18 @@ Patch_DEPR_   G_Patch_DEPR_;
 Patch         G_Patch;
 Conf          G_Conf;
 MidiMapConf   G_MidiMap;
-gdMainWindow *mainWin;
+gdMainWindow *G_MainWin;
 
 #ifdef WITH_VST
 PluginHost G_PluginHost;
 #endif
 
 
-void *thread_video(void *arg);
+void *videoThreadCb(void *arg);
 
 
-int main(int argc, char **argv) {
-
+int main(int argc, char **argv)
+{
 	G_quit = false;
 
 	init_prepareParser();
@@ -75,7 +79,7 @@ int main(int argc, char **argv) {
 	init_prepareKernelMIDI();
 	init_startGUI(argc, argv);
 	Fl::lock();
-	pthread_create(&t_video, NULL, thread_video, NULL);
+	pthread_create(&G_videoThread, NULL, videoThreadCb, NULL);
 	init_startKernelAudio();
 
 #ifdef WITH_VST
@@ -88,16 +92,16 @@ int main(int argc, char **argv) {
 	juce::shutdownJuce_GUI();
 #endif
 
-	pthread_join(t_video, NULL);
+	pthread_join(G_videoThread, NULL);
 	return ret;
 }
 
 
-
-void *thread_video(void *arg) {
+void *videoThreadCb(void *arg)
+{
 	if (G_audio_status)
 		while (!G_quit)	{
-			gu_refresh();
+			gu_refreshUI();
 #ifdef _WIN32
 			Sleep(GUI_SLEEP);
 #else
